<?php
add_action( 'init', 'zm_login_process' );
function zm_login_process() {
	if ( ! empty( $_POST['zm-login'] ) ) {
		$username = $_POST['zm-username'];
		$password = $_POST['zm-password'];
		$remember = zm_isset( $_POST['zm-remember'] ) ? true : false;
		$general = get_option( 'zm_general_option' );
		$actual_link = $_POST['zm-login-page'];
		$recaptcha = $_POST['zm-login-recaptcha'];

		if ( '' == $username|| '' == $password ) {
			wp_redirect( zm_format_url( $actual_link, 'zm_login=false' ) );
			exit();
		}

		// check login attemp
		if ( zm_isset( $general['lock_enable'] ) == 'on' ) {
			if ( get_transient( 'zm_login_attemp' ) ) {
				wp_redirect( zm_format_url( $actual_link, 'zm_login=locked' ) );
				exit();
			}
		}

		// is recaptcha enabled?
		if ( $recaptcha == 'yes' ) {
			require_once ZM_API_RECAPTCHA;

			if ( $privatekey = zm_isset( $general['rc_private_key'] ) ) {
		  		$resp = recaptcha_check_answer($privatekey,
					$_SERVER['REMOTE_ADDR'],
					$_POST['recaptcha_challenge_field'],
				$_POST['recaptcha_response_field']);

				if ( ! $resp->is_valid ) {
					// What happens when the CAPTCHA was entered incorrectly?
					wp_redirect( zm_format_url( $actual_link, 'zm_captcha=false' ) );
					exit();
		  		}
			}
		}

		$creds = array(
			'username' => $username,
			'password' => $password,
			'remember' => $remember,
		);

		// var_dump($creds);
		$member = zm_login( $creds );

		// failed
		if ( is_array( $member ) && zm_isset( $member['false'] ) ) {
			// check logged in attemp
			$value = 1;
			if ( isset( $_COOKIE['zm_login_attemp'] ) ) {
				$value = $_COOKIE['zm_login_attemp'];
				$value++;
			}

			$secure = is_ssl();

			if ( $value == 5 ) {
				set_transient( 'zm_login_attemp', true, 60 * 5 );
				@setcookie( 'zm_login_attemp', '', '', SITECOOKIEPATH, COOKIE_DOMAIN, $secure, true );
			} else {
				@setcookie( 'zm_login_attemp', $value, zm_time() + 60 * 5, SITECOOKIEPATH, COOKIE_DOMAIN, $secure, true );
			}

			if ( $member['false'] == 'not_active' ) {
				wp_redirect( zm_format_url( $actual_link, 'zm_active=false' ) );
			} else {
				wp_redirect( zm_format_url( $actual_link, 'zm_login=false' ) );
			}
			exit();

			// success
		} else {
			if ( zm_isset( $general['lock_enable'] ) == 'on' ) {
				// check IP address (prevent account sharing) cheated? go to hell yeah..
				$max = abs( $general['lock_ip'] );
				$duration = abs( $general['lock_minute'] );
				$ip = zm_get_ipaddr();

				if ( get_transient( 'zm_first_attemp_login_'.$member->ID ) ) {
					$ips = get_option( 'zm_login_ip_'.$member->ID );

					if ( ! in_array( $ip, $ips ) ) {
						$ips[] = $ip;
						update_option( 'zm_login_ip_'.$member->ID, $ips );
					}

					if ( count( $ips ) >= $max ) {
						// lock user
						global $wpdb;

						$meta = array( 'status' => 0 );
						$format[] = '%d';
						$wpdb->update( "{$wpdb->prefix}zm_members", $meta, array( 'ID' => $member->ID ), $format, array( '%d' ) );
					}
				} else {
					// store first attemp login time
					set_transient( 'zm_first_attemp_login_'.$member->ID, true, 60 * $duration );
					update_option( 'zm_login_ip_'.$member->ID, array( $ip ) );
				}
			}
			if ( $redir = zm_isset( $_GET['redir'] ) ) {

				if ( is_numeric( $redir ) ) { wp_redirect( get_permalink( $redir ) );
				} else { wp_redirect( zm_decode( $redir, 'download' ) ); }

				exit;
			} else {
				wp_redirect( get_permalink( $general['after_login_page'] ) );
				exit;
			}
		}
	}
}

function zm_login( $creds, $secure_cookie = '' ) {
	if ( ! is_array( $creds ) ) { return false; }
	if ( ! empty( $creds['remember'] ) ) {
		$creds['remember'] = true; } else {
		$creds['remember'] = false; }

		if ( '' === $secure_cookie ) {
			$secure_cookie = is_ssl(); // is_ssl() is a WP function
		}
		$member = zm_authenticate( $creds['username'], $creds['password'] );

		// echo '3. login';
		// var_dump($member);
		if ( is_array( $member ) && zm_isset( $member['false'] ) ) {
			return $member; }

		zm_set_auth_cookie( $member->ID, $creds['remember'], $secure_cookie );
		return $member;
}

function zm_authenticate( $username, $password ) {
	if ( ! function_exists( 'wp_hash_password' ) ) {
		require_once( ABSPATH . 'wp-includes/pluggable.php' ); }

	if ( empty( $username ) || empty( $password ) ) {
		return false; }

	if ( zm_isValidEmail( $username ) ) {
		$email = sanitize_email( $username );
		$member = zm_get_member_by( 'email', $username );
	} else {
		$username = sanitize_user( $username );
		$member = zm_get_member_by( 'login', $username );
	}

	// echo '1. authenticate';
	// var_dump($member);
	$password = trim( $password );
	if ( ! $member ) {
		return array( 'false' => 'not_found' ); // no member found
	}
	if ( $member->status != 1 ) {
		return array( 'false' => 'not_active' ); }
	; // membership account status is not active

	// Check the password...
	if ( ! class_exists( 'PasswordHash' ) ) {
		require_once( ABSPATH . 'wp-includes/class-phpass.php' ); }

	$wp_hasher = new PasswordHash( 8, true );
	$hashed_pass = $member->pass;
	$plain_pass = $password;

	// Echo '2. check password';
	// Var_dump($member);
	if ( $hashed_pass !== $plain_pass ) {
		if ( ! $wp_hasher->CheckPassword( $plain_pass, $hashed_pass ) ) {
			return array( 'false' => 'wrong_password' ); // wrong password
		}
	}

	return $member;
}

function zm_generate_username( $email, $first_name, $last_name = '', $regenerate = false ) {
	$first_name = utf8_decode( strtolower( remove_accents( $first_name ) ) );
	$last_name = utf8_decode( strtolower( remove_accents( $last_name ) ) );
	$username = zm_sanitize( $first_name );

	if ( ! empty( $last_name ) ) {
		$username .= "_{$last_name}"; }

	if ( $email == $first_name || empty( $username ) ) { $regenerate = true; }

	$username = trim( $username );
	if ( ! preg_match( '/^\w+$/', $username ) ) { $regenerate = true; }

	if ( $regenerate || zm_username_exists( $username ) || (strlen( $username ) < 3) ) {
		$letter = ( $regenerate ) ? 'alphanumeric' : 'numeric';
		$parts = explode( '@', $email );
		$username = ( ! empty( $parts[0] ) ) ? $parts[0] : zm_generate_secret( 6, $letter, false );

		if ( zm_username_exists( $username ) ) {
			$username .= '_' . zm_generate_secret( 4, $letter, false ); }

		// Let's check again...
		if ( zm_username_exists( $username ) ) {
			$username = zm_generate_username( $email, $first_name, $last_name, true ); }
	}

	$username = str_replace( array( '.', '-', ' ' ), '_', $username );

	return $username;
}

function zm_generate_password($email) {
	return strtolower( substr( md5( $email ), 0, 7 ) );
}

function zm_username_exists( $username ) {
	if ( $member = zm_get_member_by( 'login', $username ) ) { return $member->ID; }
	return false;
}

function zm_email_exists( $email ) {
	$email = sanitize_email( $email );
	if ( $member = zm_get_member_by( 'email', $email ) ) { return $member->ID; }
	return false;
}

function zm_set_auth_cookie( $member_id, $remember = false, $secure = '' ) {
	if ( $remember ) {
		$expiration = $expire = zm_time() + 1209600;
	} else {
		$expiration = zm_time() + 172800;
		$expire = 0;
	}

	if ( '' === $secure ) {
		$secure = is_ssl();  // is_ssl() is a WP function
	}
	if ( $secure ) {
		$auth_cookie_name = 'zm_sec_' . COOKIEHASH;
		$scheme = 'secure_auth';
	} else {
		$auth_cookie_name = 'zm_' . COOKIEHASH;
		$scheme = 'auth';
	}

	$auth_cookie = zm_generate_auth_cookie( $member_id, $expiration, $scheme );
	$logged_in_cookie = zm_generate_auth_cookie( $member_id, $expiration, 'logged_in' );

	@setcookie( $auth_cookie_name, $auth_cookie, $expire, SITECOOKIEPATH, COOKIE_DOMAIN, $secure, true );
	@setcookie( 'zm_logged_in_' . COOKIEHASH, $logged_in_cookie, $expire, SITECOOKIEPATH, COOKIE_DOMAIN, $secure, true );
	// echo SITECOOKIEPATH.'<br>';
	// echo COOKIE_DOMAIN.'<br>';
	// echo 'zm_logged_in_' . COOKIEHASH;
	// die();
	return true;
}

function zm_generate_auth_cookie( $member_id, $expiration, $scheme = 'auth' ) {
	if ( ! function_exists( 'wp_hash' ) ) {
		require_once( ABSPATH . 'wp-includes/pluggable.php' ); }

	$member = zm_member( $member_id );
	// $pass_frag = substr($member->pass, 8, 4);
	$pass_frag = 'zm';

	$key = wp_hash( $member->username . $pass_frag . '|' . $expiration, $scheme ); // wp_hash is a wp function
	$hash = hash_hmac( 'md5', $member->username . '|' . $expiration, $key );

	$cookie = $member->username . '|' . $expiration . '|' . $hash;
	return $cookie;
}

function zm_validate_auth_cookie( $cookie = '', $scheme = '' ) {
	if ( ! $cookie_elements = zm_parse_auth_cookie( $cookie, $scheme ) ) {
		return false; }

	extract( $cookie_elements, EXTR_OVERWRITE );
	$expired = $expiration;

	// Quick check to see if an honest cookie has expired
	if ( $expired < zm_time() ) {
		zm_clear_auth_cookie();
		return false;
	}

	$member = zm_get_member_by( 'login', $username );
	if ( ! $member ) {
		zm_clear_auth_cookie();
		return false;
	}

	// $pass_frag = substr($member->pass, 8, 4);
	$pass_frag = 'zm';

	if ( ! function_exists( 'wp_hash' ) ) {
		require_once( ABSPATH . 'wp-includes/pluggable.php' ); }

	$key = wp_hash( $username . $pass_frag . '|' . $expiration, $scheme );
	$hash = hash_hmac( 'md5', $username . '|' . $expiration, $key );

	if ( $hmac != $hash ) {
		zm_clear_auth_cookie();
		return false;
	}

	return $member->ID;
}

function zm_parse_auth_cookie( $cookie = '', $scheme = '' ) {
	if ( empty( $cookie ) ) {
		switch ( $scheme ) {
			case 'auth':
				$cookie_name = 'zm_' . COOKIEHASH;
				break;
			case 'secure_auth':
				$cookie_name = 'zm_sec_' . COOKIEHASH;
				break;
			case 'logged_in':
				$cookie_name = 'zm_logged_in_' . COOKIEHASH;
				break;
			default:
				if ( is_ssl() ) {
					$cookie_name = 'zm_sec_' . COOKIEHASH;
					$scheme = 'secure_auth';
				} else {
					$cookie_name = 'zm_' . COOKIEHASH;
					$scheme = 'auth';
				}
	    }

		// ($_SERVER);
		// var_dump($cookie_name);
		// var_dump($_COOKIE);
		// die();
		if ( empty( $_COOKIE[$cookie_name] ) ) {
			return false; }
		$cookie = $_COOKIE[$cookie_name];
	}

	$cookie_elements = explode( '|', $cookie );
	if ( count( $cookie_elements ) != 3 ) {
		return false; }

	list($username, $expiration, $hmac) = $cookie_elements;
	return compact( 'username', 'expiration', 'hmac', 'scheme' );
}

function zm_clear_auth_cookie() {
	@setcookie( 'zm_' . COOKIEHASH, false, -1, SITECOOKIEPATH, COOKIE_DOMAIN );
	@setcookie( 'zm_sec_' . COOKIEHASH, false, -1, SITECOOKIEPATH, COOKIE_DOMAIN ); // for secure cookie
	@setcookie( 'zm_logged_in_' . COOKIEHASH, false, -1, SITECOOKIEPATH, COOKIE_DOMAIN );
}

function is_zm_logged_in() {
	if ( $member = zm_get_current_member() ) { return true; }
	return false;
}

function zm_logout() {
	zm_clear_auth_cookie();
	do_action( 'zm_logged_out' ); // hook for any action after logged out...
}

add_action( 'template_redirect', 'zm_process_logout', 2 );
function zm_process_logout() {
	if ( isset( $_GET['zm_action'] ) && $_GET['zm_action'] == 'logout' ) {
		zm_logout();
	}
}

add_action( 'zm_logged_out', 'zm_after_logout_redirect', 50 );
function zm_after_logout_redirect() {
	$general = get_option( 'zm_general_option' );
	$login_url = ( ! empty( $general['login_page'] ) ) ? get_permalink( $general['login_page'] ) : get_bloginfo( 'url' );
	$after_logout_url = ( ! empty( $general['logout_page'] ) ) ? $general['logout_page'] : $login_url;

	wp_redirect( $after_logout_url );
	exit;
}

function zm_get_products() {
	global $wpdb;
	$products = $wpdb->get_results( "SELECT * FROM `{$wpdb->prefix}zm_products` ORDER BY `title` ASC" );
	if ( ! $products ) { return false; }
	return $products;
}

function zm_get_product( $product_id ) {
	global $wpdb;

	$product_id = intval( $product_id );
	$product = wp_cache_get( $product_id, 'zm_product' );
	if ( ! $product ) {
		// grab product data from database, if there's no product in cache
		$sql = "SELECT * FROM `{$wpdb->prefix}zm_products` WHERE `ID` = %d";
		if ( ! $product = $wpdb->get_row( $wpdb->prepare( $sql, $product_id ) ) ) {
			return false; }

		if ( isset( $product->metadata ) ) {
			$product->meta = maybe_unserialize( $product->metadata );
			unset( $product->metadata );
		}

		if ( isset( $product->autoresponder ) ) {
			$product->resp = maybe_unserialize( $product->autoresponder );
			unset( $product->autoresponder );
		}

		wp_cache_add( $product_id, $product, 'zm_product' );
	}
	return $product;
}

function zm_get_productby_sku( $sku, $pricenum = 1 ) {
	global $wpdb;

	$opt = $pricenum == 1 ? " OR `vendor` = ''" : '';

	$sql = $wpdb->prepare( "SELECT * FROM `{$wpdb->prefix}zm_sku` WHERE `payment` = %s AND `sku` = %s AND (`vendor` = %s ".$opt.')', 'zaxaa', $sku, $pricenum );

	if ( ! $rows = $wpdb->get_results( $sql ) ) { return false; }
	$product = false;

	foreach ( $rows as $row ) {
		$product = zm_get_product( $row->product_id );
	}

	return $product;
}

function zm_generate_secret( $length = 16, $letter = 'alphanumeric', $caps = false ) {

	if ( $letter == 'alphanumeric' ) {
		$characters = '1234567890abcdefghijklmnopqrstuvwxyz'; } else if ( $letter == 'numeric' ) {
		$characters = '1234567890'; } else if ( $letter = 'alpha' ) {
			$characters = 'abcdefghijklmnopqrstuvwxyz'; }

		$secret = '';
		for ( $p = 0; $p < $length; $p++ ) {
			$secret .= $characters[mt_rand( 0, strlen( $characters ) -1 )];
		}
		return (( $caps ) ? strtoupper( $secret ) : $secret);
}

function zm_esc( &$str, $allowed_tags = '', $texturize, $remove_lines = false ) {
	if ( ! isset( $value ) ) { return ''; }

	$value = trim( stripslashes( $str ) );
	if ( $remove_lines ) {
		$value = str_replace( array( "\n", "\r", "\r\n" ), ' ', $value ); }

	if ( empty( $allowed_tags ) ) {
		$value = strip_tags( $value ); } else {
		$value = strip_tags( $str, $allowed_tags );
		$value = $value;
		}

		if ( $texturize ) {
			$value = wptexturize( $value ); }

		return $value;
}

function zm_sanitize( &$value, $default = null ) {
	if ( ! isset( $value ) ) { $value = $default; }
	return trim( stripslashes( $value ) );
}

function zm_isset( &$value, $default = null, $default_on_empty = false ) {
	if ( isset( $value ) ) { $temp = ( $default_on_empty && empty( $value ) ) ? $default : $value;
	} else { $temp = $default; }
	return $temp;
}

function zm_dump( $vars, $echo = true ) {
	$dump = '<pre>' . print_r( $vars, true ) . '</pre>';
	if ( $echo ) { echo $dump; }
	return $dump;
}

function zm_format_url( $page_id, $query_str ) {
	$query_string = '';
	$link = '';
	$url = ( is_numeric( $page_id ) && $page_id > 0 ) ? get_permalink( $page_id ) : $page_id;

	if ( $url == get_bloginfo( 'url' ) && ! zm_verify_wpindex() ) {
		$url = trailingslashit( get_bloginfo( 'url' ) ) . 'index.php';
	}

	$url = ( stristr( $url, 'index.php' ) ) ? $url : trailingslashit( $url );
	if ( get_option( 'show_on_front' ) == 'page' && get_option( 'page_on_front' ) == $page_id ) {
		$query_string = '?' . $query_str;
		$link = $url . $query_string;
	} else {
		if ( strpos( $url, '?' ) ) {
			$query_string = '&' . $query_str;
			$link = $url . $query_string;
		} else {
			$query_string = '?' . $query_str;
			$link = $url . $query_string;
		}
	}
	return $link;
}

if ( ! is_admin() ) { add_action( 'init', 'zm_wpindex_status' ); }
function zm_wpindex_status() {
	if ( isset( $_GET['zm_verify'] ) && $_GET['zm_verify'] == 'true' ) { die( 'Verified' );
	} else { return; }
}

function zm_verify_wpindex() {
	if ( get_transient( 'zm_index_verified' ) == 'true' ) { true; }
	$result = wp_remote_get(
		trailingslashit( get_bloginfo( 'url' ) ) . '?zm_verify=true',
		array(
			'timeout' => 120,
			'httpversion' => '1.1',
		)
	);

	if ( is_wp_error( $result ) ) {
		// do nothing
	} else {
		if ( isset( $result['body'] ) && $result['body'] == 'Verified' ) {
			set_transient( 'zm_index_verified', 'true', 60 * 60 * 12 );
			return true;
		}
	}

	return false;
}

function zm_validate_url( $url ) {
	if ( filter_var( $url, FILTER_VALIDATE_URL ) ) {
		return true; } else {
		return false; }
}

function zm_time($date='now') {

	/*
	$wp_timezone = get_option('timezone_string');
    $timezone = ( !empty($wp_timezone) ) ? $wp_timezone : date_default_timezone_get();
    $new_date = new DateTime($date, new DateTimeZone($timezone));
	$date = $new_date->format('H:i:s'); */

	return strtotime( $date );
}

function zm_get_ipaddr() {
	$client  = @$_SERVER['HTTP_CLIENT_IP'];
	$forward = @$_SERVER['HTTP_X_FORWARDED_FOR'];
	$remote  = @$_SERVER['REMOTE_ADDR'];
	$ip 	 = '0.0.0.0';

	if ( filter_var( $client, FILTER_VALIDATE_IP ) ) {
		$ip = $client;
	} else if ( filter_var( $forward, FILTER_VALIDATE_IP ) ) {
		$ip = $forward;
	} else if ( filter_var( $remote, FILTER_VALIDATE_IP ) ) {
		$ip = $remote;
	}

	return $ip;
}


function zm_format_recurring($every, $mode) {
	$string = '';

	if ( $every > 1 ) {
		if ( $mode == 'D' ) { $string = 'per '.$every . ' Days';
		} else if ( $mode == 'W' ) { $string = 'per '.$every . ' Weeks';
		} else if ( $mode == 'M' ) { $string = 'per '.$every . ' Months';
		} else if ( $mode == 'Y' ) { $string = 'per '.$every . ' Years'; }
	} else {
		if ( $mode == 'D' ) { $string = 'Daily';
		} else if ( $mode == 'W' ) { $string = 'Weekly';
		} else if ( $mode == 'M' ) { $string = 'Monthly';
		} else if ( $mode == 'Y' ) { $string = 'Yearly'; }
	}

	return $string;
}

function zm_isValidEmail($email) {
	return filter_var( $email, FILTER_VALIDATE_EMAIL );
}

function zm_get_all($db, $id='', $type='') {
	global $wpdb;

	switch ( $db ) {
		case 'product':
			// Get all Products
			if ( $type == 'payment' ) {
				$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_products ORDER BY type DESC" );
			} else {
				if ( is_array( $id ) ) {
					$conditions = '';
					if ( $txn_time = zm_isset( $id['zm_cre_time'] ) ) {
						if ( $txn_date = zm_time_condition( 'date', $txn_time, $id['zm_from'], $id['zm_to'] ) ) {
							$conditions .= ' WHERE '.$txn_date; }
					}

					if ( $product = zm_isset( $id['zm_product'] ) ) {
						if ( $product != 'all' ) {
							$conditions .= $conditions ? ' AND title LIKE "%'.$product.'%"' : ' WHERE title LIKE "%'.$product.'%"';
						}
					}

					if ( $type = zm_isset( $id['zm_ptype'] ) ) {
						if ( $type != 'all' ) {
							$conditions .= $conditions ? ' AND type="'.$type.'"' : ' WHERE type="'.$type.'"';
						}
					}

					$order_by = 'date DESC';

					if ( $od = zm_isset( $id['zm_od'] ) ) {
						$order_by = 'date '.$od;
					}

					if ( $op = zm_isset( $id['zm_op'] ) ) {
						if ( $op != 'all' ) {
							$order_by = 'title '.$op;
						}
					}

					$start = ($id['start'] * $id['limit']) -$id['limit'];
					$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_products".$conditions." ORDER BY {$order_by} LIMIT {$start},{$id['limit']}" );
				} else {
					$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_products ORDER BY date DESC" );
				}
			}

			break;

		case 'coupon':
			// Get all Coupons
			if ( $type == 'shortcode' ) {
				$data = $wpdb->get_results("SELECT T1.*, T2.title FROM {$wpdb->prefix}zm_coupons  AS T1
                    LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID
					GROUP BY T1.product_id");
			} else {
				if ( is_array( $id ) ) {
					$start = ($id[0] * $id[1]) -$id[1];
					$data = $wpdb->get_results("SELECT T1.*, T2.title FROM {$wpdb->prefix}zm_coupons  AS T1
                    LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID
					LIMIT {$start},{$id[1]}");
				} else {
					$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_coupons" );
				}
			}

		break;

		case 'member':
			// Get all Members
			if ( $type == '30days' ) {
				$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_members WHERE date >= ".strtotime( '30 days ago' ) );
			} else {
				if ( is_array( $id ) ) {
					$conditions = '';
					if ( $txn_time = zm_isset( $id['zm_reg_time'] ) ) {
						if ( $txn_date = zm_time_condition( 'date', $txn_time, $id['zm_from'], $id['zm_to'] ) ) {
							$conditions .= ' WHERE '.$txn_date; }
					}

					if ( $email = zm_isset( $id['zm_email'] ) ) {
						if ( $email != 'all' ) {
							$conditions .= $conditions ? ' AND email LIKE "%'.$email.'%"' : ' WHERE email LIKE "%'.$email.'%"';
						}
					}

					if ( $username = zm_isset( $id['zm_username'] ) ) {
						if ( $username != 'all' ) {
							$conditions .= $conditions ? ' AND username LIKE "%'.$username.'%"' : ' WHERE username LIKE "%'.$username.'%"';
						}
					}

					if ( $lock = zm_isset( $id['zm_lock'] ) ) {
						if ( $lock != 'all' ) {
							$lock = ($lock == 2) ? 0 : $lock;
							$conditions .= $conditions ? ' AND status = '.$lock : ' WHERE status = '.$lock;
						}
					}

					if ( $status = zm_isset( $id['zm_status'] ) ) {
						if ( $status != 'all' ) {
							if ( $status == 1 ) {
								$payments = zm_get_all( 'payment', '', 'paying' );

								if ( $payments ) {
									$ids = '';
									foreach ( $payments as $payment ) {
										$ids .= $ids ? ', '.$payment->member_id : $payment->member_id;
									}

									$conditions .= $conditions ? ' AND ID IN ('.$ids.')' : ' WHERE ID IN ('.$ids.')';
								} else {
									$conditions .= $conditions ? ' AND ID=0' : ' WHERE ID=0';
								}
							} else {
								$payments = zm_get_all( 'payment', '', 'nonpaying' );

								if ( $payments ) {
									$ids = '';
									foreach ( $payments as $payment ) {
										$ids .= $ids ? ', '.$payment->member_id : $payment->member_id;
									}

									$conditions .= $conditions ? ' AND ID IN ('.$ids.')' : ' WHERE ID IN ('.$ids.')';
								} else {
									$conditions .= $conditions ? ' AND ID=0' : ' WHERE ID=0';
								}
							}
						}
					}

					$start = ($id['start'] * $id['limit']) -$id['limit'];

					$query = "SELECT * FROM {$wpdb->prefix}zm_members".$conditions." ORDER BY date DESC LIMIT {$start},{$id['limit']}";

					// die($query);
					$data = $wpdb->get_results( $query );
				} else {
					$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_members ORDER BY date DESC" );
				}
			}

		break;

		case 'protect':
			// Get all protects data by product_id
			if ( is_array( $id ) ) {
				if ( $type == 'file' ) {
					$query = 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id = -1 AND '.$id[0].'="'.$id[1].'"'; } else if ( $type == 'category' ) {
					$query = 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id = -2 AND '.$id[0].' IN ('.$id[1].')'; } else if ( $type == 'file_local' ) {
						$query = 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id = -1 AND filename LIKE "local_%" AND '.$id[0].'="'.$id[1].'"'; } else if ( $type == 'file_s3' ) {
						$query = 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id = -1 AND filename LIKE "s3_%" AND '.$id[0].'='.$id[1]; } else {
							$query = 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE '.$id[0].'='.$id[1]; }

						$data = $wpdb->get_results( $query );
			} else {
				if ( $type == 'file' ) {
					$data = $wpdb->get_results( 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id = -1 AND product_id='.$id ); } else if ( $type == 'file_s3' ) {
					$data = $wpdb->get_results( 'SELECT * FROM (SELECT *, COUNT(filename) as count FROM `'.$wpdb->prefix.'zm_protects` AS T1 WHERE post_id = -1 AND filename LIKE "s3_%" GROUP BY filename) AS T2 WHERE T2.product_id='.$id.' AND T2.count=1' ); } else if ( $type == 'meta' ) {
						$data = $wpdb->get_results( 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id='.$id ); } else {
						$data = $wpdb->get_results( 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE product_id='.$id ); }
			}
			break;

		case 'payment':
			// Get all Payments
			if ( $type == 'access' ) {
				$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_payments WHERE member_id=".$id.' AND status <> 4 AND expired_date >= '.zm_time() ); } else if ( $type == 'last10' ) {
				$data = $wpdb->get_results("SELECT T1.*, T2.title, T3.username, T3.email FROM `{$wpdb->prefix}zm_payments` AS T1
                LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID
                LEFT JOIN `{$wpdb->prefix}zm_members` AS T3 ON T1.member_id=T3.ID
				ORDER BY ID DESC LIMIT 10");
				} else if ( $type == '30days' ) {
					$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_payments WHERE txn_date >= ".strtotime( '30 days ago' ) );
				} else if ( $type == 'dailycheck' ) {
					$data = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}zm_payments WHERE type='subscription' AND status IN (1, 2) ORDER BY ID DESC" );
				} else if ( $type == 'nonpaying' ) {
					$data = $wpdb->get_results( "SELECT member_id FROM {$wpdb->prefix}zm_payments WHERE type='subscription' AND status IN (2, 4) GROUP BY member_id ORDER BY ID DESC" );
				} else if ( $type == 'paying' ) {
					$data = $wpdb->get_results( "SELECT member_id FROM {$wpdb->prefix}zm_payments WHERE type='subscription' AND status=1 GROUP BY member_id ORDER BY ID DESC" );
				} else if ( $type == 'history' ) {
					if ( is_array( $id ) ) {
						$data = $wpdb->get_results( "SELECT T1.*, T2.type as p_type, T2.* FROM {$wpdb->prefix}zm_payments AS T1 LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID WHERE T1.member_id=".$id[1].' AND T1.product_id='.$id[0].' ORDER BY T1.ID DESC' );
					} else {
						$data = $wpdb->get_results( "SELECT T1.*, SUM(T1.amount) as amount, T2.title FROM {$wpdb->prefix}zm_payments AS T1 LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID WHERE T1.member_id=".$id.' GROUP BY T1.product_id ORDER BY T1.ID DESC' );
					}
				} else {
					$data = $wpdb->get_results( "SELECT T1.*, T2.title FROM {$wpdb->prefix}zm_payments AS T1 LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID WHERE member_id=".$id.' ORDER BY ID DESC' );
				}

			break;

		case 'report':
			// Get all Reports
			if ( $type == 'performance' ) {
				$conditions = '';
				if ( $txn_time = zm_isset( $id['zm_txn_time'] ) ) {
					if ( $txn_date = zm_time_condition( 'txn_date', $txn_time, $id['zm_from'], $id['zm_to'] ) ) {
						$conditions .= ' AND '.$txn_date; }
				}

				$query = "SELECT T1.title, T1.type, T1.subs_num, T1.subs_mode,
                        (SELECT COUNT(DISTINCT member_id) FROM `{$wpdb->prefix}zm_payments` WHERE product_id=T1.ID{$conditions}) AS total_member,
                        (SELECT COUNT(*) FROM `{$wpdb->prefix}zm_payments` WHERE product_id=T1.ID AND status=4{$conditions}) AS refunded,
                        (SELECT COUNT(*) FROM `{$wpdb->prefix}zm_payments` WHERE product_id=T1.ID AND status=2{$conditions}) AS cancelled,
                        (SELECT COUNT(*) FROM `{$wpdb->prefix}zm_payments` WHERE product_id=T1.ID AND status <> 2{$conditions}) AS not_cancelled,
                        (SELECT SUM(amount) FROM `{$wpdb->prefix}zm_payments` WHERE product_id=T1.ID AND status IN(1,3){$conditions}) AS revenue
                        FROM `{$wpdb->prefix}zm_products` AS T1
						WHERE T1.type <> 'free' ORDER BY T1.date DESC";

				$data = $wpdb->get_results( $query );
			} else if ( $type == 'engagement' ) {
				$conditions = '';
				if ( $txn_time = zm_isset( $id['zm_txn_time'] ) ) {
					if ( $txn_date = zm_time_condition( 'T1.date', $txn_time, $id['zm_from'], $id['zm_to'] ) ) {
						$conditions .= 'WHERE '.$txn_date; }
				}

				$query = "SELECT T1.*, T2.username,
                        COUNT(DISTINCT page_id) AS total_page,
                        COUNT(DISTINCT ip_addr) AS total_ip
                        FROM `{$wpdb->prefix}zm_access_log` AS T1
                        LEFT JOIN `{$wpdb->prefix}zm_members` AS T2 ON T1.member_id=T2.ID
                        {$conditions}
                        GROUP BY T1.member_id
						ORDER BY T1.date DESC";

				$data = $wpdb->get_results( $query );
			} else {
				if ( is_array( $id ) ) {
					$conditions = '';
					if ( $txn_time = zm_isset( $id['zm_txn_time'] ) ) {
						if ( $txn_date = zm_time_condition( 'T1.txn_date', $txn_time ) ) {
							$conditions .= ' WHERE '.$txn_date; }
					}

					if ( $product = zm_isset( $id['zm_product'] ) ) {
						if ( $product != 'all' ) {
							$conditions .= $conditions ? ' AND T1.product_id='.$product : ' WHERE T1.product_id='.$product;
						}
					}

					if ( $currency = zm_isset( $id['zm_txn_currency'] ) ) {
						$conditions .= $conditions ? ' AND T1.currency="'.$currency.'"' : ' WHERE T1.currency="'.$currency.'"';
					}

					if ( isset( $id['zm_txn_status'] ) ) {
						if ( $id['zm_txn_status'] != 'all' ) {
							$status = zm_isset( $id['zm_txn_status'] );
							$conditions .= $conditions ? ' AND T1.status='.$status : ' WHERE T1.status='.$status;
						}
					}

					$start = ($id['start'] * $id['limit']) -$id['limit'];

					$query = "SELECT T1.*, T2.title, T3.username, T3.email
                                FROM {$wpdb->prefix}zm_payments AS T1
                                    LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID
									LEFT JOIN `{$wpdb->prefix}zm_members` AS T3 ON T1.member_id=T3.ID ".$conditions." ORDER BY T1.ID DESC LIMIT {$start},{$id['limit']}";

					// die($query);
					$data = $wpdb->get_results( $query );
				} else {
					$data = $wpdb->get_results("SELECT T1.*, T2.title, T3.username, T3.email FROM {$wpdb->prefix}zm_payments AS T1
                                            LEFT JOIN `{$wpdb->prefix}zm_products` AS T2 ON T1.product_id=T2.ID
                                            LEFT JOIN `{$wpdb->prefix}zm_members` AS T3 ON T1.member_id=T3.ID
											ORDER BY T1.ID DESC");
				}
			}
			break;

		default:
		break;
	}

	return $data;
}

function zm_check_page($id, $type='post') {
	global $general_option, $wpdb;

	$member = zm_get_current_member();

	if ( ! $member ) {
		wp_redirect( get_permalink( $general_option['login_page'] ) );
		exit;
	}

	if ( $member->status != 1 ) {
		// EASY TIGER.. PLEASE CONFIRM YOUR REGISTRATION
		wp_redirect( zm_format_url( $general_option['login_page'], 'zm_active=false' ) );
		exit;
	}

	$metadata = zm_get_all( 'payment', $member->ID, 'access' );
	if ( $metadata ) {
		$product_list = array();
		$product_purchase = array();

		// collecting product ids
		foreach ( $metadata as $meta ) {
			if ( ! in_array( $meta->product_id, $product_list ) ) {
				$product_list[] = $meta->product_id;

				// USED IN EVERGREEN FUNCTION BELOW
				if ( $meta->type == 'subscription' ) {
					$rmeta = zm_first_recurring( $meta->product_id );
					$product_purchase[$meta->product_id] = $rmeta->begin_date;
				} else {
					$product_purchase[$meta->product_id] = $meta->txn_date;
				}
			}
		}

		if ( count( $product_list ) > 1 ) {
			$ids = implode( ', ', $product_list );
		} else {
			$ids = $product_list[0];
		}

		if ( $type == 'post' ) {
			// POST/PAGE/CATEGORY PROTECTION
			$data = $wpdb->get_results( 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id='.$id.' AND product_id IN ('.$ids.')' );
			// check protected category
			if ( ! $data ) {
				$categories = get_the_category( $id );
				$cat_ids = array();
				if ( $categories ) {
					foreach ( $categories as $category ) {
						$cat_ids[] = '"category_'.$category->cat_ID.'"';
					}

					// list of categories
					if ( count( $cat_ids ) > 1 ) {
						$category_ids = implode( ', ', $cat_ids );
					} else {
						$category_ids = $cat_ids[0];
					}

					$data = $wpdb->get_results( 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id=-2 AND filename IN ('.$category_ids.') AND product_id IN ('.$ids.')' );
				}
			}
		} else {
			// FILE PROTECTION
			$data = $wpdb->get_results( 'SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE post_id=-1 AND filename="'.$id.'" AND product_id IN ('.$ids.')' );
		}

		if ( $data ) {
			$temp_day = array(
				'D' => 'day',
				'W' => 'week',
				'M' => 'month',
				'Y' => 'year',
			);

			// *IS UNAVAILABLE
			$unavailable = true;
			// *IS EXPIRED
			$expired = true;

			foreach ( $data as $row ) {

				// DRIP END IS NOT USED (LIFETIME)
				if ( ! $row->d_end_used ) {
					$expired = false;
				}

				if ( $unavailable || $expired ) {
					// STANDARD
					if ( $row->d_start_mode == 'X' ) {
						if ( $row->d_start < zm_time() ) {
							$unavailable = false;
						}

						if ( $row->d_end > zm_time() ) {
							$expired = false;
						}
					} else {
						// EVERGREEN
						$now = zm_time();
						$start = strtotime( $row->d_start .' '. $temp_day[$row->d_start_mode] );
						$end = ($row->d_end_used) ? strtotime( $row->d_end .' '. $temp_day[$row->d_end_mode] ) : strtotime( '19 Jan 2038 03:14:07 UTC' ); // LET'S SAY 19 Jan 2038 03:14:07 UTC IS LIFETIME

						$start -= $now;
						$end -= $now;

						$dif = absint( $product_purchase[$row->product_id] );

						if ( $dif + $start <= $now ) {
							$unavailable = false;
						}

						if ( $dif + $end >= $now ) {
							$expired = false;
						}
					}
				} else {
					// FOUND : STOP SEARCHING.. TAKE A REST.. REDIRECT VISITOR TO PAGE
					// ACCESS LOG
					break;
				}
			}

			// OOPS..YOUR PAGE IS NOT AVAILABLE RIGHT NOW
			if ( $unavailable ) {
				wp_redirect( get_permalink( $general_option['unavailable_page'] ) );
				exit;
			}

			// SORRY..EXPIRED DUDE..
			if ( $expired ) {
				wp_redirect( get_permalink( $general_option['expired_page'] ) );
				exit;
			}

			if ( $type == 'post' ) { zm_set_access_log( $member->ID, $id ); }
		} else {
			// EASY TIGER..ACCESS ERROR
			@setcookie( 'zm_access_er', $id, zm_time() + 172800, SITECOOKIEPATH );
			wp_redirect( get_permalink( $general_option['access_error_page'] ) );
			exit;
		}
	} else {
		// EASY TIGER..ACCESS ERROR
		@setcookie( 'zm_access_er', $id, zm_time() + 172800, SITECOOKIEPATH );
		wp_redirect( get_permalink( $general_option['access_error_page'] ) );
		exit;
	}
}

function zm_first_recurring($id) {
	global $wpdb;

	$user_id = zm_get_current_member_id();

	$first_recurring = $wpdb->get_row(
		$wpdb->prepare("SELECT * FROM `{$wpdb->prefix}zm_payments`
            WHERE `product_id`= %s
            AND `member_id`= %d
			ORDER BY ID ASC LIMIT 1",
			$id, $user_id
		)
	);

	if ( ! $first_recurring ) {
		return false; }

	return $first_recurring;
}



/**
 * Encode string by secret key and unlimited level of encoding
 */

function zm_encode($str_to_encode, $secretkey, $level = 1) {
	$result = bin2hex( zm_encoder( $str_to_encode, $secretkey ) );

	if ( $level == 1 ) {
		return $result; }

	return zm_encode( $result, $secretkey, --$level );
}

/**
 * Decode string by secret key and unlimited level of encryption
 */
function zm_decode($str_to_decode, $secretkey, $level = 1) {
	$result = zm_encoder( zm_hex2bin( $str_to_decode ), $secretkey );

	if ( $level == 1 ) {
		return $result; }

	return zm_decode( $result, $secretkey, --$level );
}

/**
 * Encode string by secret key
 */
function zm_encoder($data, $pwd) {
	$pwd_length = strlen( $pwd );
	for ( $i = 0; $i < 255; $i++ ) {
		$key[$i] = ord( substr( $pwd, ($i % $pwd_length) + 1, 1 ) );
		$counter[$i] = $i;
	}
	$x = 0;
	for ( $i = 0; $i < 255; $i++ ) {
		$x = ($x + $counter[$i] + $key[$i]) % 255;
		$temp_swap = $counter[$i];
		$counter[$i] = $counter[$x];
		$counter[$x] = $temp_swap;
	}
	$Zcrypt = '';
	$a = 0;
	$j = 0;
	for ( $i = 0; $i < strlen( $data ); $i++ ) {
		$a = ($a + 1) % 255;
		$j = ($j + $counter[$a]) % 255;
		$temp = $counter[$a];
		$counter[$a] = $counter[$j];
		$counter[$j] = $temp;
		$k = $counter[(($counter[$a] + $counter[$j]) % 255)];
		$Zcipher = ord( substr( $data, $i, 1 ) ) ^ $k;
		$Zcrypt .= chr( $Zcipher );
	}
	return $Zcrypt;
}

/**
 * Convert hex to bin
 */
function zm_hex2bin($hexdata) {
	$bindata = '';
	for ( $i = 0;$i < strlen( $hexdata );$i += 2 ) {
		$bindata .= chr( hexdec( substr( $hexdata,$i,2 ) ) );
	}
	return $bindata;
}

function zm_get_row($db, $id, $output_type = OBJECT) {
	global $wpdb;

	switch ( $db ) {
		case 'product':
			// Get a Product
			$data = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}zm_products WHERE ID = ".$id, $output_type );
		break;

		case 'coupon':
			// Get a Coupon
			$data = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}zm_coupons WHERE ID = ".$id, $output_type );
		break;

		case 'member':
			// Get a Member
			$data = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}zm_members WHERE ID = ".$id, $output_type );
		break;

		case 'payment':
			// Get a Payment
			$data = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}zm_payments WHERE ID = ".$id, $output_type );
		break;

		case 'protect':
			// Get a Protect
			if ( is_array( $id ) ) {
				$data = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}zm_protects WHERE product_id = ".$id[0].' AND post_id='.$id[1], $output_type );
			}
		break;
		default:
		break;
	}

	wp_reset_query();
	return $data;
}

function zm_duration_str( $num, $mode ) {
	if ( $mode == 'D' ) {
		$m = 'day'; } else if ( $mode == 'W' ) {
		$m = 'week'; } else if ( $mode == 'M' ) {
			$m = 'month'; } else if ( $mode == 'Y' ) {
			$m = 'year'; }

			$str = '';
			$str .= "+{$num} {$m}";
			if ( $num > 1 ) {
				$str .= 's'; }

			return $str;
}

function zm_currencies() {
	$currencies = array(
		'AUD' => 'Australian Dollars ($)',
		'CAD' => 'Canadian Dollars ($)',
		'EUR' => 'Euros (&euro;)',
		'GBP' => 'Pounds Sterling (&pound;)',
		'USD' => 'US Dollars ($)',
	);

	return $currencies;
}

function zm_discount_price($mode, $discount, $price) {
	if ( $mode == 1 ) {
		$cut = ($price * $discount) / 100;
		return round( $price - $cut, 2 );
	} else {
		return round( $price - $discount, 2 );
	}

}

function zm_translate_mode($num, $mode) {
	if ( $mode == 'D' ) {
		if ( $num > 1 ) {
			return $num.' days'; } else {
			return 'a day'; }
	} else if ( $mode == 'W' ) {
		if ( $num > 1 ) {
			return $num.' weeks'; } else {
			return 'a week'; }
	} else if ( $mode == 'M' ) {
		if ( $num > 1 ) {
			return $num.' months'; } else {
			return 'a month'; }
	} else if ( $mode == 'Y' ) {
		if ( $num > 1 ) {
			return $num.' years'; } else {
			return 'a year'; }
	}
}

function zm_translate_rc_mode($num, $mode) {
	if ( $mode == 'D' ) {
		if ( $num > 1 ) {
			return 'for each '.$num.' days'; } else {
			return ' daily'; }
	} else if ( $mode == 'W' ) {
		if ( $num > 1 ) {
			return 'for each '.$num.' weeks'; } else {
			return ' weekly'; }
	} else if ( $mode == 'M' ) {
		if ( $num > 1 ) {
			return 'for each '.$num.' months'; } else {
			return ' monthly'; }
	} else if ( $mode == 'Y' ) {
		if ( $num > 1 ) {
			return 'for each '.$num.' years'; } else {
			return ' yearly'; }
	}
}

// hide post from visitors
add_action( 'pre_get_posts', 'zm_exclude_post_from_blog' );
function zm_exclude_post_from_blog( $query ) {
	global $wpdb;
	if ( $query->is_main_query() && $query->is_home() ) {
		$member = zm_get_current_member();

		if ( ! $member ) {
			$data = $wpdb->get_results( "SELECT DISTINCT(post_id) FROM {$wpdb->prefix}zm_protects WHERE post_id > 0" );

			// die(var_dump($data));
			$hide_me = array();
			foreach ( $data as $row ) {
				$hide_me[] = $row->post_id;
			}

			$args = array(
			 	'posts_per_page' => -1,
			  	'post_status' => 'publish',
			);

			$posts = get_posts( $args );
			$include_me = array();
			foreach ( $posts as $post ) {
				if ( ! in_array( $post->ID, $hide_me ) ) {
					$include_me[] = $post->ID;
				}
			}

			// die(var_dump($posts));
			$query->set( 'post__in', $include_me );
		}
	}
}

function zm_status($id, $type=false) {

	if ( $id == 0 ) {
		return ( ! $type ? '<span class="gpf-label round">PENDING</span>' : 'Pending');
	} else if ( $id == 1 ) {
		return ( ! $type ? '<span class="gpf-label success round">COMPLETED</span>' : 'Completed');
	} else if ( $id == 2 ) {
		return ( ! $type ? '<span class="gpf-label alert round">CANCELED</span>' : 'Canceled');
	} else if ( $id == 3 ) {
		return ( ! $type ? '<span class="gpf-label secondary round">EXPIRED</span>' : 'Expired');
	} else if ( $id == 4 ) {
		return ( ! $type ? '<span class="gpf-label alert round">REFUNDED</span>' : 'Refunded');
	}
}

function zm_payment_type_is($value) {
	if ( $value == 'free' ) {
		return 'Free';
	} else if ( $value == 'onetime' ) {
		return 'One-time';
	} else if ( $value == 'subscription' ) {
		return 'Recurring Billing';
	}
}

// Get Autoresponder Text Fields
function zm_extract_fields( $code, $data ) {
	$fields = array();
	$total_field = count( $code[0] );

	// die(var_dump($code[0]));
	// Get Fields
	for ( $i = 0; $i < ($total_field); $i++ ) {
		$field    = str_replace( "'", '"', zm_isset( $code[0][$i] ) );
		$field    = str_replace( '-', '_zm_ds_', $field );
		$field    = str_replace( ' ', '_zm_sp_', $field );
		$field    = str_replace( '[', '_zm_ob_', $field );
		$field    = str_replace( ']', '_zm_cb_', $field );

		preg_match( '/(name=[\'"]\w+[\'"])/', $field, $args );
		// die(var_dump($args));
		$name = substr( $args[0], 6, strlen( $args[0] ) -7 );
		$name = str_replace( '_zm_sp_', ' ', $name );
		$name = str_replace( '_zm_ds_', '-', $name );
		$name = str_replace( '_zm_ob_', '[', $name );
		$name = str_replace( '_zm_cb_', ']', $name );
		// die(var_dump($name));
		$nfield = strtolower( $name );

		if ( preg_match( '/email/', $nfield, $args ) ) {
			$cls_name = 'zm-email-field';
			$value = zm_sanitize( $data['email'] );
		} else if ( preg_match( '/mail/', $nfield, $args ) ) {
			$cls_name = 'zm-email-field';
			$value = zm_sanitize( $data['email'] );
		} else if ( preg_match( '/name/', $nfield, $args ) ) {
			$cls_name = 'zm-fname-field';
			$value = zm_sanitize( $data['first_name'] );
		} else if ( preg_match( '/first/', $nfield, $args ) ) {
			$cls_name = 'zm-fname-field';
			$value = zm_sanitize( $data['first_name'] );
		} else if ( preg_match( '/fname/', $nfield, $args ) ) {
			$cls_name = 'zm-fname-field';
			$value = zm_sanitize( $data['first_name'] );
		} else if ( preg_match( '/last/', $nfield, $args ) ) {
			$cls_name = 'zm-lname-field';
			$value = zm_sanitize( $data['last_name'] );
		} else if ( preg_match( '/lname/', $nfield, $args ) ) {
			$cls_name = 'zm-lname-field';
			$value = zm_sanitize( $data['last_name'] );
		}

		$fields[]  = '<input type="hidden" name="' . $name . '" class=" ' . $cls_name . '" value="' . $value . '" />';
	}

	return $fields;
}

function zm_insert_query( $table, $meta, $format ) {
	global $wpdb;

	$reindexed_array = array_values( $meta );

	$query = "INSERT INTO {$wpdb->prefix}{$table} ( ".(implode( ', ', array_keys( $meta ) )).') VALUES ( '.(implode( ', ', $format )).' )';

	$wpdb->query(
		$wpdb->prepare( $query, $reindexed_array )
	);

	return $wpdb->insert_id;
}

function zm_set_access_log($member_id, $id) {
	// Add an access log
	$meta = array(
		'member_id' => $member_id,
		'page_id' => $id,
		'ip_addr' => zm_get_ipaddr(),
		'date' => strtotime( 'now' ),
	);

	$format = array(
	'%d',
	'%d',
	'%s',
	'%d',
	);

	$insert_id = zm_insert_query( 'zm_access_log', $meta, $format );
}

function zm_get_download_link($product_id) {
	$product = zm_get_product( $product_id );

	if ( $product->download_id < 1 ) {
		if ( $product->download_id == -1 ) {
			return $product->thanks_url;
		}

		return '#';
	} else {
		return get_permalink( $product->download_id );
	}
}

function zm_frontend_style() {
	wp_enqueue_style( 'zm-fp', ZM_FLOWPLAYER.'skin/minimalist.css' );
	wp_enqueue_style( 'zm-layout', ZM_URL . 'css/layout.css' );
	wp_enqueue_style( 'zm-font-awesome-min', ZM_URL . 'css/font-awesome.min.css' );
		wp_enqueue_style( 'zm-font-awesome-ie7', ZM_URL . 'css/font-awesome-ie7.min.css' );
}

function zm_frontend_script() {
	wp_enqueue_script( 'jquery-zm-fp', ZM_FLOWPLAYER.'flowplayer.min.js' );
	wp_enqueue_script( 'jquery-validation', ZM_URL . 'js/jquery.validate.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'zm-layout-js', ZM_URL . 'js/layout.js' );
}
