<?php
// Plugin update checker...
$zm_update_checker = new PluginUpdateChecker(
    'http://www.getprofitsfast.com/zm_api/?action=get_metadata&slug=zaxaamember', ZM_ROOT, 'zaxaamember'
);

add_filter("puc_manual_check_message-{$zm_update_checker->slug}", 'zm_update_messages', 10, 2);
function zm_update_messages( $message, $status ) {
    if ( $status == 'update_available' )
        $message = 'A new version of Zaxaa Member is available.';
    else if ( $status == 'no_update' )
        $message = 'Zaxaa Member is up to date.';

    return $message;
}

require_once( ZM_PATH . 'ref.php' );
require_once( ZM_LIBS . 'mail.php');
require_once( ZM_LIBS . 'membership.php');
require_once( ZM_LIBS . 'payment.php');
require_once( ZM_LIBS . 'functions.php');
require_once( ZM_LIBS . 'shortcode.php');

if ( is_admin() ) {
    require_once(ZM_ADMIN . 'admin.php');
    require_once(ZM_ADMIN . 'admin-js.php');
    require_once(ZM_ADMIN . 'admin-functions.php');
    require_once(ZM_ADMIN . 'admin-meta.php');
    // Load Zaxaa Member TinyMce
    require_once(ZM_LIBS . 'tinymce/zm-tinymce.php');
}else{
    include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

    // check for plugin using plugin name
    if ( !is_plugin_active('easy-quick-member/easy-quick-member.php') ) {
          //plugin is activated
          add_action('wp_head', 'zm_frontend_style');
        add_action('wp_footer', 'zm_frontend_script');
    }
}

require_once( ZM_LIBS . 'widgets.php');

//do_action('zm_load_payments'); // load available payment files...

register_deactivation_hook(__FILE__, 'zm_deactivation');

function zm_deactivation() {
    wp_clear_scheduled_hook('zm_daily_event');
}

register_activation_hook( __FILE__, 'zm_install');
add_action('zm_daily_event', 'zm_do_this_daily');

function zm_do_this_daily() {
    global $wpdb;

    // checked protected page every day (only for exact date (drip end))
    $data = $wpdb->get_results('SELECT * FROM `'.$wpdb->prefix.'zm_protects` WHERE d_end_mode="X" and is_expired=0');

    if ($data){
        $ids = array();

        foreach ($data as $row){
            if (zm_time() > $row->d_end){
                $ids[] = $row->ID;
            }
        }

        if (count($ids) > 0){
            $ids = implode(', ', $ids);
            $wpdb->query("UPDATE `".$wpdb->prefix."zm_protects` SET is_expired = 1 WHERE ID IN (".$ids.")");
        }
    }

    // ----------------------------------------------------
    // checked expired subscription payment

    $data = zm_get_all('payment', '', 'dailycheck');

    if ($data){
        $ids = array();

        foreach ($data as $row){
            if (zm_time() > $row->expired_date){
                $ids[] = $row->ID;
            }
        }

        if (count($ids) > 0){
            $ids = implode(', ', $ids);
            $wpdb->query("UPDATE `".$wpdb->prefix."zm_payments` SET status = 3 WHERE ID IN (".$ids.")");
        }
    }
}

function zm_install() {
    global $wpdb;

    $installed_ver = get_option('zm_db_version');
    if ( $installed_ver != ZM_DB_VERSION ) {
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

        $table = "{$wpdb->prefix}zm_members";
        $sql = "CREATE TABLE {$table} (
                `ID` bigint(20) NOT NULL AUTO_INCREMENT,
                `username` varchar(100) NOT NULL,
                `email` varchar(100) NOT NULL,
                `pass` varchar(255) NOT NULL,
                `first_name` varchar(100) NOT NULL,
                `last_name` varchar(100) NOT NULL,
                `status` tinyint(1) NOT NULL,
                `paypal_id` varchar(100) NOT NULL,
                `metadata` longtext NOT NULL,
                `date` int(11) NOT NULL,
                UNIQUE KEY id (ID)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_products";
        $sql .= "CREATE TABLE {$table} (
                `ID` bigint(20) NOT NULL AUTO_INCREMENT,
                `title` varchar(100) NOT NULL,
                `download_id` bigint(20) NOT NULL,
                `thanks_url` varchar(255) NOT NULL,
                `type` varchar(64) NOT NULL,
                `is_trial` tinyint(1) NOT NULL,
                `trial_price` decimal(6,2) NOT NULL,
                `ot_price` decimal(6,2) NOT NULL,
                `rc_price` decimal(6,2) NOT NULL,
                `subs_num` int(11) NOT NULL,
                `trial_num` int(11) NOT NULL,
                `subs_mode` varchar(10) NOT NULL,
                `trial_mode` varchar(10) NOT NULL,
                `rebill_times` int(11) NOT NULL,
                `metadata` longtext NOT NULL,
                `status` tinyint(1) NOT NULL,
                `autoresponder` longtext NOT NULL,
                `gotowebinar` longtext NOT NULL,
                `date` int(11) NOT NULL,
                UNIQUE KEY id (ID)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_sku";
        $sql .= "CREATE TABLE {$table} (
                `ID` bigint(20) NOT NULL AUTO_INCREMENT,
                `payment` varchar(100) NOT NULL,
                `product_id` bigint(20) NOT NULL,
                `sku` varchar(255) NOT NULL,
                `vendor` varchar(255) NOT NULL,
                UNIQUE KEY id (ID)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_payments";
        $sql .= "CREATE TABLE {$table} (
                `ID` bigint(20) NOT NULL AUTO_INCREMENT,
                `product_id` bigint(20) NOT NULL,
                `member_id` bigint(20) NOT NULL,
                `type` varchar(64) NOT NULL,
                `paysys` varchar(64) NOT NULL,
                `receipt` varchar(64) NOT NULL,
                `amount` decimal(6,2) NOT NULL,
                `is_rebill` tinyint(1) NOT NULL,
                `status` tinyint(1) NOT NULL,
                `currency` varchar(5) NOT NULL DEFAULT 'USD',
                `txn_id` varchar(100) NOT NULL,
                `other_id` varchar(100) NOT NULL,
                `ipaddr` varchar(32) NOT NULL,
                `begin_date` int(11) NOT NULL,
                `expired_date` int(11) NOT NULL,
                `txn_date` int(11) NOT NULL,
                UNIQUE KEY id (ID)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_subscription_schedules";
        $sql .= "CREATE TABLE {$table} (
                `ID` bigint(20) NOT NULL AUTO_INCREMENT,
                `product_id` bigint(20) NOT NULL,
                `member_id` bigint(20) NOT NULL,
                `orig_tx_id` bigint(20) NOT NULL,
                `paysys` varchar(64) NOT NULL,
                `metadata` longtext NOT NULL,
                `retries` int(11) NOT NULL,
                `bill_date` int(11) NOT NULL,
                UNIQUE KEY id (ID)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_protects";
        $sql .= "CREATE TABLE {$table} (
                `ID` bigint(20) NOT NULL AUTO_INCREMENT,
                `product_id` bigint(20) NOT NULL,
                `post_id` bigint(20) NOT NULL,
                `filename` varchar(255) NOT NULL,
                `d_start` int(11) NOT NULL,
                `d_end` int(11) NOT NULL,
                `d_start_mode` varchar(10) NOT NULL,
                `d_end_mode` varchar(10) NOT NULL,
                `d_end_used` tinyint(1) NOT NULL,
                `is_expired` tinyint(1) NOT NULL,
                `date` int(11) NOT NULL,
                UNIQUE KEY id (ID)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_access_log";
        $sql .= "CREATE TABLE {$table} (
                `log_id` bigint(20) NOT NULL AUTO_INCREMENT,
                `member_id` bigint(20) NOT NULL,
                `page_id` bigint(20) NOT NULL,
                `ip_addr` varchar(32) NOT NULL,
                `date` int(11) NOT NULL,
                UNIQUE KEY id (log_id)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_error_log";
        $sql .= "CREATE TABLE {$table} (
                `log_id` bigint(20) NOT NULL AUTO_INCREMENT,
                `member_id` bigint(20) NOT NULL,
                `receipt` varchar(100) NOT NULL,
                `url` varchar(255) NOT NULL,
                `ip_addr` varchar(32) NOT NULL,
                `referrer` varchar(255) NOT NULL,
                `error` varchar(255) NOT NULL,
                `type` varchar(20) NOT NULL,
                `date` int(11) NOT NULL,
                UNIQUE KEY id (log_id)
            ) DEFAULT CHARSET=utf8;";

        $table = "{$wpdb->prefix}zm_ipn_log";
        $sql .= "CREATE TABLE {$table} (
                `log_id` bigint(20) NOT NULL AUTO_INCREMENT,
                `tx_id` bigint(20) NOT NULL,
                `product_id` bigint(20) NOT NULL,
                `member_id` bigint(20) NOT NULL,
                `pay_email` varchar(100) NOT NULL,
                `paysys` varchar(100) NOT NULL,
                `receipt` varchar(100) NOT NULL,
                `status` tinyint(1) NOT NULL,
                `postdata` longtext NOT NULL,
                `date` int(11) NOT NULL,
                UNIQUE KEY id (log_id)
            ) DEFAULT CHARSET=utf8;";
        // create or update database...
        dbDelta($sql);

        update_option('zm_db_version', ZM_DB_VERSION);
    }

    wp_schedule_event( zm_time(), 'twicedaily', 'zm_daily_event');
}

// load all option
$general_option = get_option('zm_general_option');

add_action('plugins_loaded', 'zm_update_db_check');
function zm_update_db_check() {
    if ( get_option('zm_db_version') != ZM_DB_VERSION ) {
        zm_install();
    }

    $username = ZAXAA_USERNAME;
    if ( get_option('zm_username') == '' && !empty($username) ) {
        update_option('zm_username', $username);
    }
}

function zm_deleteDirectory($dir) {
    if (!file_exists($dir)) return true;

    if (!is_dir($dir) || is_link($dir)) return unlink($dir);

    foreach (scandir($dir) as $item) {
        if ($item == '.' || $item == '..') continue;
        if (!zm_deleteDirectory($dir . "/" . $item)) {
            chmod($dir . "/" . $item, 0777);
            if (!zm_deleteDirectory($dir . "/" . $item)) return false;
        };
    }
    return rmdir($dir);
}

add_action('plugins_loaded', 'zm_create_download_folder');
function zm_create_download_folder(){
    //create download folder
    $downloadpath = ZM_DOWNLOAD;
    $wp_dir     = ABSPATH . '/wp-content/uploads/';

    //zm_deleteDirectory($downloadpath);
    //die();

    if ( !is_writeable( $wp_dir ) ) {
        @chmod($wp_dir, 0777);
    }

    if ( !is_dir( $downloadpath ) && is_writable($wp_dir) ) {
        if ( function_exists('wp_mkdir_p') )
            @wp_mkdir_p($downloadpath);
        else
            @mkdir(str_replace('//', '/', $downloadpath), 0777, true);
    }

    if ( is_dir( $downloadpath ) && is_writeable( $downloadpath ) ) {
        $myFile = $downloadpath . '/.htaccess';
        if (!file_exists($myFile)){
            $fh = @fopen($myFile, 'w') or wp_die('can\'t open file '.$myFile);
            $stringData  = 'deny from all';

            @fwrite($fh, $stringData);
            @fclose($fh);
        }
    }
}

add_action('init', 'zm_initial_setup');
function zm_initial_setup(){
    if ( get_option('zm_email_setup') === FALSE ) {
        $receipt = '--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------

Hello,

Thank you for purchasing [%product%].

--------------------------------------------------------------------
PURCHASE INFORMATION
--------------------------------------------------------------------
Receipt: [%receipt%]
Product: [%product%]
Period: [%period%]
Total Payment: [%amount%]
Payment Method: [%paysys%]
Customer Name: [%first_name%] [%last_name%]
Customer Email: [%email_addr%]

Product Access:
[%download%]

Once again, thank you for your purchase.

Sincerely,
'.zm_isset(get_bloginfo('name'), 'YOUR_NAME_HERE').'

--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------';

        $welcome = '--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------

Hello,

Thank you for purchasing [%product%].

You can access it here:
[%download%]

When prompted to login, use the credentials below:

Username: [%username%]
Password: [%password%]

Once again, thank you for your purchase.

Sincerely,
'.zm_isset(get_bloginfo('name'), 'YOUR_NAME_HERE').'

--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------';

        $subscription = '--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------

Hello,

This is to notify you that the following subscription has been canceled and will not be billed again:

Product name: [%product%]

Sincerely,
'.zm_isset(get_bloginfo('name'), 'YOUR_NAME_HERE').'

--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------';

    $forgot_email = '--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------

Hello,

We have received your request to change your password.

Please click this link to generate a new password:
[%generate_password_url%]

Sincerely,
'.zm_isset(get_bloginfo('name'), 'YOUR_NAME_HERE').'

--------------------------------
This is a system-generated email. Do NOT reply to this email as no one will see it.
--------------------------------';
        $data = array(
            'from_name' => get_bloginfo('name'),
            'from_email' => get_bloginfo('admin_email'),
            'mailer' => 'php',
            'smtp_host'	=> '',
            'smtp_port'	=> '',
            'encryption' => '',
            'is_auth' => 'off',
            'smtp_username' => '',
            'smtp_password' => '',
            'welcome_email' => array('send_admin' => false, 'subject' => 'Your login credentials for [%product%]', 'body' => $welcome),
            'receipt_email' => array('send_admin' => false, 'enable' => false, 'subject' => 'Your receipt for [%product%]', 'body' => $receipt),
            'subscription_email' => array('send_admin' => false, 'enable' => false, 'subject' => 'You\'ve canceled your subscription to [%product%]', 'body' => $subscription),
            'forgot_email' => array('subject' => 'Change Password Request', 'body' => $forgot_email)
        );

        add_option('zm_email_setup', $data);
    }

    if (get_option('zm_general_option') === FALSE){
        $newpage = array();
          $newpage['post_status'] = 'publish';
          $newpage['post_author'] = 1;
        $newpage['post_type'] = 'page';

        $general = array(
            'is_powered' => 'on',
            'is_hideunavailable' => 'off',
            'aff_link'	=> '',
            'az_enable' => 'off',
            'az_api' => '',
            'az_key'	=> '',
            'rc_enable' => 'off',
            'rc_public_key' => '',
            'rc_private_key' => '',
            'gtw_enable' => 'off',
            'gtw_key' => '',
            'lock_enable' => 'off',
            'lock_ip' => '5',
            'lock_minute' => '60',
        );

        $newpage['post_title'] = 'Zaxaa Member - Members Login';
        $newpage['post_content'] = '[zm_login_form]';
        if ($page = get_page_by_title($newpage['post_title'], 'OBJECT') ) $general['login_page'] = $page->ID;
        else $general['login_page'] = @wp_insert_post( $newpage );

        $newpage['post_title'] = 'Zaxaa Member - Membership Home';
        $newpage['post_content'] = "Welcome to [insert membership name here] Members Area.<br><br>
        Here you'll find lots of resources to help you start learning how you can get [insert benefit here].<br><br>
        [zm_purchased_products_links].<br><br>
        If you have any questions, please do not hesitate to contact us at [insert support desk url here].";
        if ($page = get_page_by_title($newpage['post_title'], 'OBJECT') ) $general['after_login_page'] = $page->ID;
        else $general['after_login_page'] = @wp_insert_post( $newpage );

        $newpage['post_title'] = 'Zaxaa Member - Members Profile';
        $newpage['post_content'] = '[zm_profile_page]';
        if ($page = get_page_by_title($newpage['post_title'], 'OBJECT') ) $general['profile_page'] = $page->ID;
        else $general['profile_page'] = @wp_insert_post( $newpage );

        $newpage['post_title'] = 'Zaxaa Member - Insufficient Access';
        $newpage['post_content'] = 'You do NOT have sufficient permissions to access this page. You have to upgrade your membership level before you can view this page.';
        if ($page = get_page_by_title($newpage['post_title'], 'OBJECT') ) $general['access_error_page'] = $page->ID;
        else $general['access_error_page'] = @wp_insert_post( $newpage );

        $newpage['post_title'] = 'Zaxaa Member - Not Yet Available';
        $newpage['post_content'] = 'Content Unavailable.';
        if ($page = get_page_by_title($newpage['post_title'], 'OBJECT') ) $general['unavailable_page'] = $page->ID;
        else $general['unavailable_page'] = @wp_insert_post( $newpage );

        $newpage['post_title'] = 'Zaxaa Member - Content Expired';
        $newpage['post_content'] = 'Content Expired';
        if ($page = get_page_by_title($newpage['post_title'], 'OBJECT') ) $general['expired_page'] = $page->ID;
        else $general['expired_page'] = @wp_insert_post( $newpage );

        add_option('zm_general_option', $general);
    }
}

if (!is_admin()){
    add_action('template_redirect', 'zm_render_page', 10);
}

function zm_render_page(){
    global $post;

    if (is_single() || is_page()){
        if ($data = zm_is_protected($post->ID)){
            $general = get_option('zm_general_option');

            //IF ADMIN
            if (is_user_logged_in()){
                global $current_user;
                  get_currentuserinfo();

                  if ($current_user->roles[0] === 'administrator')
                      return;
            }

            if (is_zm_logged_in()){
                zm_check_page($post->ID);
            }else{
                wp_redirect(zm_format_url($general['login_page'], 'redir=' . $post->ID )); exit;
            }
        }
    }
}

add_action('init', 'zm_reset_password');
function zm_reset_password(){
    if(isset($_GET['page']) && $_GET['page'] == 'reset' && isset($_GET['us'])){
        $temp = zm_decode($_GET['us'], 'reset_pass');

        $data = explode('|', $temp);

        //CHECK IS MEMBER EXIST
        $member = zm_get_row('member', $data[0]);

        if ($member){
            $password = zm_generate_password($member->email);
            zm_update('member', array($data[0], $password), 'password');

            //SENT EMAIL WITH NEW PASSWORD HERE..

        }

        wp_redirect(site_url());
        exit;
    }
}

add_action('init', 'zm_update_profile');
function zm_update_profile(){
    if ( zm_isset($_GET['action']) == 'update' && zm_isset($_GET['mode']) == 'membership') {
        if(isset($_POST['zm-nonce'])){
            global $wpdb;

            $meta = array(
                'email' => $_POST['zm_email'],
                'first_name' => $_POST['zm_fname'],
                'last_name' => $_POST['zm_lname'],
            );

            $format = array('%s', '%s', '%s');

            // Change Password
            if ($_POST['zm_password'] != ''){
                $meta['pass'] = wp_hash_password($_POST['zm_password']);
                $format[] = '%s';

                $temp_passwords = get_option('zm_temp_pass');
                if ($temp_passwords) {
                    unset($temp_passwords[$_POST['zm-nonce']]);
                    update_option('zm_temp_pass', $temp_passwords);
                }

            }

            if($wpdb->update( "{$wpdb->prefix}zm_members", $meta, array( 'ID' => $_POST['zm-nonce'] ), $format, array( '%d' ) )){
                // clean caches
                wp_cache_delete($_POST['zm-nonce'], 'zm_members');
                wp_cache_delete($_POST['zm_cache_username'], 'zm_memberlogins');
                wp_cache_delete($_POST['zm_email'], 'zm_memberemail');

                wp_redirect(zm_format_url($_POST['zm_url'], 'mode=membership&action=update&updated=true'));
            }else{
                wp_redirect(zm_format_url($_POST['zm_url'], 'mode=membership&action=update&updated=false'));
            }
            exit;
        }
    }
}

add_action('init', 'zm_confirmation');
function zm_confirmation(){
    if ( zm_isset($_GET['mode']) == 'register' && zm_isset($_GET['link'])) {

        if(isset($_COOKIE['__zm_'.$_GET['link']])){
            $code = explode('|', zm_decode($_GET['link'], 'registration'));
            $product_id = $code[1];
            $member_id = $_COOKIE['__zm_'.$_GET['link']];

            //security purpose
            if(zm_is_subscribed($member_id, $product_id)){
                $member = zm_get_member_by('id',  $member_id);
                $product = zm_get_product($product_id);

                if($member){
                    global $wpdb;
                    $general = get_option('zm_general_option');

                    if ($member->status == 1){
                        //CLEAR COOKIE
                        @setcookie('__zm_'.$_GET['link'], '', zm_time()-172800, SITECOOKIEPATH);
                        zm_error('You have activated your account. Please login <a href="'.get_permalink($general['login_page']).'">here</a>');
                    }

                    $meta = array('status' => 1);
                    $format = array('%d');

                    if($wpdb->update( "{$wpdb->prefix}zm_members", $meta, array( 'ID' => $member->ID ), $format, array( '%d' ) )){
                        // clean caches
                        wp_cache_delete($member->ID, 'zm_members');
                        wp_cache_delete($member->username, 'zm_memberlogins');
                        wp_cache_delete($member->email, 'zm_memberemail');

                        //Auto login user
                        zm_set_auth_cookie($member->ID, false, is_ssl());

                        if (zm_isset($product->download_id, false, true)){
                            if ($product->download_id > 0){
                                $page = get_page($product->download_id);
                                if ($page){
                                    wp_redirect(zm_format_url($product->download_id, 'zm_active=true'));
                                }else{
                                    wp_redirect(zm_format_url($general['after_login_page'], 'zm_active=true'));
                                }
                            }else{
                                wp_redirect($product->thanks_url);
                            }
                        }else{
                            wp_redirect(zm_format_url($general['after_login_page'], 'zm_active=true'));
                        }
                    }else{
                        wp_redirect(zm_format_url(zm_isset($general['login_page']), 'zm_active=false'));
                    }
                    exit;
                }
            }
        }
        zm_error('Invalid URL.');
    }
}

add_action('init', 'zm_change_password');
function zm_change_password(){
    if ( zm_isset($_GET['mode']) == 'change_password' && zm_isset($_GET['link'])) {
        $code = explode('|', zm_decode($_GET['link'], 'password'));
        $member = zm_get_member_by('id',  $code[1]);
        $general = get_option('zm_general_option');
        if($member){
            global $wpdb;

            $new_pass = substr(md5(rand(0, 99).'-'.$code[1].'-'.rand(0, 99)), 0, 6);
            //$meta = array('pass' => wp_hash_password($new_pass));
            $meta = array('pass' => $new_pass);
            $format = array('%s');

            if($wpdb->update( "{$wpdb->prefix}zm_members", $meta, array( 'ID' => $member->ID ), $format, array( '%d' ) )){
                // clean caches
                wp_cache_delete($member->ID, 'zm_members');
                wp_cache_delete($member->username, 'zm_memberlogins');
                wp_cache_delete($member->email, 'zm_memberemail');

                zm_send_email(3, $member->ID, $new_pass);

                // logging in and then redirect...
                zm_set_auth_cookie( $member->ID);

                wp_redirect(zm_format_url(zm_isset($general['profile_page']), 'reset_pass=true'));
            }else{
                wp_redirect(zm_format_url(zm_isset($general['login_page']), 'reset_pass=false'));
            }
            exit;
        }else{
            wp_redirect(zm_format_url(zm_isset($general['login_page']), 'member=false'));
            exit;
        }
    }
}

function zm_error($message){
    echo '<style>
    body{
        background: #ededed;
        color: #555;
        font-family: consolas, courier;
        font-size: 13px;
        line-height: 1.4em;
        font-weight:bold;
    }

    table{
        margin: 0 auto;
        background: #fff;
        border-left: 4px solid #dd3d36;
        -webkit-box-shadow: 0px 1px 1px 0px rgba(0,0,0,0.1);
        box-shadow: 0px 1px 1px 0px rgba(0,0,0,0.1);
        border-collapse: collapse;
    }

    a{
        color: #0074a2;
        -moz-transition: all .1s ease-in-out;
        -webkit-transition: all .1s ease-in-out;
        transition: all .1s ease-in-out;
    }

    table td{
        padding: 10px 20px;
    }
    </style>';
    echo '<table><tr><td style="background:#dd3d36; color:#fff; font-size:20px;">!</td><td>'.$message.'</td></tr></table>';
    die();
}

function zaxaa_referral_url( $url = 'https://www.zaxaa.com', $echo = true ) {
    $username = ZAXAA_USERNAME;
    if ( empty($username) && get_option('zm_username') != '' )
        $username = get_option('zm_username');

    if ( empty($username) )
        $ref_url = $url;
    else {
        $ref_url = add_query_arg('ref', $username, $url);
    }

    if ( $echo ) echo $ref_url;
    else return $ref_url;
}

add_action('init', 'zm_override_server_timezone');
function zm_override_server_timezone(){
    $wp_timezone = get_option('timezone_string');
    $timezone = ( !empty($wp_timezone) ) ? $wp_timezone : date_default_timezone_get();

    if ($wp_timezone != date_default_timezone_get()) date_default_timezone_set($timezone);
}
