<?php

/* ======================================
 * EMAIL-RELATED FUNCTIONS
 * ====================================== */

add_action('phpmailer_init','zm_smtp', 20);
function zm_smtp( $phpmailer ) {
	$emails = get_option('zm_email_setup');
	$mailer = zm_isset($emails['mailer']);
	if( $mailer != 'smtp' )
		return false;
	
	$phpmailer->Mailer = 'smtp';
	
	$secure = ( zm_isset($emails['encryption']) == 'no' ) ? '' : strtoupper(zm_sanitize($emails['encryption']));
	$phpmailer->SMTPSecure = $secure;
	$phpmailer->Host = zm_sanitize($emails['smtp_host']);
	$phpmailer->Port = zm_sanitize($emails['smtp_port']);

	$is_auth = ( zm_isset($emails['is_auth']) == 'on' ) ? TRUE : FALSE;
	if ( $is_auth ) {
		$phpmailer->SMTPAuth = TRUE;
		$phpmailer->Username = zm_sanitize($emails['smtp_username']);
		$phpmailer->Password = zm_sanitize($emails['smtp_password']);
	}
	return true;
}

function zm_parse_mail_tags( $content, $member_id, $product_id = 0, $tx_id = 0, $pass = '' ) {
	global $general_option;
	
	$paysys = 'free';
	$receipt = 'free';
	$period = 'Lifetime Access';
	$amount = 0;
	
	$content = zm_sanitize($content);
	if ( !$m = zm_member($member_id) )
		return $content;
	
	if ( $tx_id )
		$payment = zm_get_payment($tx_id);
	
	$product_id = ( !empty($payment->product_id) ) ? $payment->product_id : $product_id;
	$product = zm_get_product($product_id);
	
	$home_url = ( !empty($general_option['after_login_page']) ) ? get_permalink($general_option['after_login_page']) : get_bloginfo('url');
	$product_url = ( !empty($product->download_id) ) ? get_permalink($product->download_id) : $home_url;
	
	// Parse member data
	$content = str_replace('[%username%]', zm_sanitize($m->username), $content);
	$content = str_replace('[%first_name%]', zm_sanitize($m->first_name), $content);
	$content = str_replace('[%last_name%]', zm_sanitize($m->last_name), $content);
	$content = str_replace('[%password%]', zm_sanitize($pass), $content);
	$content = str_replace('[%email_addr%]', zm_sanitize($m->email), $content); 
	
	$content = str_replace('[%members_home%]', zm_sanitize($home_url), $content); 
	
	if ( !empty($product->ID) )
		$content = str_replace('[%product%]', zm_sanitize($product->title), $content);
	
	if ( !empty($payment->ID) ) {
		$amount = $payment->amount;
		$paysys = ($payment->paysys != '-') ? zm_sanitize($payment->paysys) : 'free';
		$receipt = ($payment->receipt != '-') ? zm_isset(zm_sanitize($payment->receipt), 'free') : 'free';
		$period = ( $payment->type == 'onetime' || $payment->type == 'free') ? 'Lifetime Access' : date("d/m/Y", $payment->begin_date) . ' - ' . date("d/m/Y", $payment->expired_date);
	}
	
	$content = str_replace('[%amount%]', number_format($amount, 2, '.', ''), $content);
	$content = str_replace('[%paysys%]', ucwords($paysys), $content);
	$content = str_replace('[%receipt%]', $receipt, $content);
	$content = str_replace('[%period%]', $period, $content);
	$download_url = zm_format_url(get_bloginfo('url'), "zm_return={$paysys}&zm_id={$product_id}&rcpt={$receipt}");
	$content = str_replace('[%download%]', $download_url, $content);
		

	return $content;
}

function zm_welcome_email( $member_id, $plain_pass = '', $product_id = 0, $tx_id = 0 ) {
	if ( !$m = zm_member($member_id) )
		return false;
	
	$emails = get_option('zm_email_setup');
	$welcome = zm_isset($emails['welcome_email']);
	
	if ($plain_pass){
		//Save temp password
		$temp_passwords = get_option('zm_temp_pass');
		if (!$temp_passwords) $temp_passwords = array();
		
		$temp_passwords[$member_id] = $plain_pass;
		update_option('zm_temp_pass', $temp_passwords);
	}else{
		$plain_pass = $m->pass;
		
		//if encrypted
		if (substr($plain_pass, 0, 3) === '$P$B'){
			$plain_pass = '-your existing password-';
		}
	}
	
	$subject = zm_parse_mail_tags(zm_sanitize($welcome['subject']), $member_id, $product_id, $tx_id, $plain_pass);
	$body = zm_parse_mail_tags(zm_sanitize($welcome['body']), $member_id, $product_id, $tx_id, $plain_pass);
	
	zm_mail($m->email, $subject, $body);
	
	if ( zm_isset($welcome['send_admin']) == 'on' ) {
		// send email notification to admin here...
		$subject = '['.get_bloginfo('name').'] New User Registration';
		$body = 'New user is registered to your site.';
		zm_mail('', $subject, $body, true);
	}
}

/* add_action('zm_payment_completed', 'zm_receipt_email', 10, 1);
function zm_receipt_email( $tx_id ) {
	if ( !$p = zm_get_payment($tx_id) )
		return false;
		
	if ( !$m = zm_member($p->member_id) )
		return false;
		
	$emails = get_option('zm_email_setup');
	$receipt = zm_isset($emails['receipt_email']);
	
	if ( zm_isset($receipt['enable'], 'on', true) == 'on' ) {
		$subject = zm_parse_mail_tags(zm_sanitize($receipt['subject']), $m->ID, $p->product_id, $tx_id);
		$body = zm_parse_mail_tags(zm_sanitize($receipt['body']), $m->ID, $p->product_id, $tx_id);
		
		$send = zm_mail($m->email, $subject, $body);
	}
	
	if ( zm_isset($receipt['send_admin']) == 'on' ) {
		// send email notification to admin here...
		$subject = '['.get_bloginfo('name').'] New Payment';
		$body = 'You have new payment on your site.';
		zm_mail('', $subject, $body, true);
	}
}

add_action('zm_subscription_canceled', 'zm_cancel_email');
function zm_cancel_email( $tx_id ) {
	if ( $p = zm_get_payment($tx_id) )
		return false;
	
	if ( !$m = zm_member($p->member_id) )
		return false;
	
	$emails = get_option('zm_email_setup');
	$cancel = zm_isset($emails['subscription_email']);
	
	$subject = zm_parse_mail_tags(zm_sanitize($cancel['subject']), $m->ID, $p->product_id, $tx_id);
	$body = zm_parse_mail_tags(zm_sanitize($cancel['body']), $m->ID, $p->product_id, $tx_id);
	
	zm_mail($m->email, $subject, $body);
	
	if ( zm_isset($cancel['send_admin']) == 'on' ) {
		// send email notification to admin here...
		$subject = '['.get_bloginfo('name').'] Subscription Cancel';
		$body = 'User '.$m->username.' ('.$m->email.') has canceled her/his subscription.';
		zm_mail('', $subject, $body, true);
	}
}
*/

function zm_mail( $to, $subject, $body, $admin_notify = false, $add_headers = '' ) {
	$emails = get_option('zm_email_setup');
	$from_email = zm_isset($emails['from_email'], get_bloginfo('admin_email'), true);
	$from_name = zm_isset($emails['from_name'], get_bloginfo('name'), true);
	
	$subject = strip_tags(zm_sanitize($subject));
	$body = strip_tags(zm_sanitize($body));
	
	if ( !function_exists('wp_mail') )
		require_once(ABSPATH . 'wp-includes/pluggable.php');
		
	$headers = 'From: ' . $from_name . ' <' . $from_email . '>' . "\r\nContent-Type: text/plain; charset=utf-8\r\n";
	$headers .= $add_headers;
	if ( $admin_notify )
		$send = wp_mail($from_email, $subject, $body, $headers);
	else
		$send = wp_mail($to, $subject, $body, $headers);
	
	if ( !$send ) return false;
	return true;
}

function zm_send_email($type, $member_id, $data=false){
	$email_setup = get_option('zm_email_setup');
	$member = zm_get_member_by('id', $member_id);
	
	if ($type == 1){ //CONFIRMATION EMAIL
		$title = $email_setup['confirmation_email']['subject'];
		$body = $email_setup['confirmation_email']['body'];
		
		$title = str_replace('[%product%]', $data['product'], $title);
		$title = str_replace('[%username%]', $member->username, $title);
		$body = str_replace('[%product%]', $data['product'], $body);
		$body = str_replace('[%username%]', $member->username, $body);
		
		$encode = zm_encode('zm|'.$member_id.'|'.$data['id'], 'registration');
		$url = site_url().'/?mode=register&link='.$encode;
		$body = str_replace('[%confirmation_url%]', $url, $body);
	}else if ($type == 2){ //FORGOT PASSWORD EMAIL
		$title = $email_setup['forgot_email']['subject'];
		$body = $email_setup['forgot_email']['body'];
		
		$title = str_replace('[%username%]', $member->username, $title);
		$body = str_replace('[%username%]', $member->username, $body);
		$url = site_url().'/?mode=change_password&link='.zm_encode('zm|'.$member_id, 'password');
		$body = str_replace('[%generate_password_url%]', $url, $body);
	}else if ($type == 3){ //CHANGE PASSWORD CONFIRMED, SEND NEW PASSWORD
		$title = 'Your New Password';
		$body = 'Here is your new credential:
			
Username: [%username%]
Password: [%password%]
		';
		
		$body = str_replace('[%username%]', $member->username, $body);
		$body = str_replace('[%password%]', $data, $body);
	}
	
	// send email to user
	$send = zm_mail( $member->email, $title, $body);
	
	if ( !$send ) return false;
	return true;
}


add_action('wp_ajax_zm_test_mail', 'zm_test_mail_callback');
function zm_test_mail_callback(){
	
	$body = 'If you\'re reading this email, it means your test email is successful. Do not forget to smile :)';
	$send = zm_mail( trim($_POST['email']), '['.get_bloginfo('name').'] Test Email', $body);
	
	if ($send){
		die('sent');
	}

	die('failed');
}

if ( is_admin() ) {
	add_action('wp_ajax_zm_send_forgot', 'zm_send_forgot_callback');
	add_action('wp_ajax_nopriv_zm_send_forgot', 'zm_send_forgot_callback' );
}

function zm_send_forgot_callback(){
	$email = $_POST['email'];
	
	if ($member = zm_get_member_by('email', $email)){
		zm_send_email(2, $member->ID);
		die('okay');
	}else{
		die('failed');
	}
}
