<?php

/* ======================================
 * MEMBERSHIP-RELATED FUNCTIONS
 * ====================================== */
 
function zm_update_member( $memberdata ) {
	if ( !is_array($memberdata) )
		return false;

	$ID = (int) $memberdata['ID'];
	// First, get all of the original fields
	$member_obj = zm_member($ID);
	$member = get_object_vars($member_obj);

	// Escape data pulled from DB.
	$member = add_magic_quotes($member);

	// If password is changing, hash it now.
	if ( !empty($memberdata['pass']) ) {
		if ( !function_exists('wp_hash_password') )
			require_once(ABSPATH . 'wp-includes/pluggable.php');
		
		$plaintext_pass = $memberdata['pass'];
		$memberdata['pass'] = wp_hash_password($plaintext_pass);
		
		//Update temp password
		$temp_passwords = get_option('zm_temp_pass');
		if (!$temp_passwords) $temp_passwords = array();
		
		$temp_passwords[$ID] = $plaintext_pass;
		update_option('zm_temp_pass', $temp_passwords);
	}

	wp_cache_delete($member['email'], 'zm_memberemail');

	// Merge old and new fields with new fields overwriting old ones.
	$memberdata = array_merge($member, $memberdata);
	$member_id = zm_insert_member($memberdata);

	// Update the cookies if the password changed.
	$current_member_id = zm_get_current_member_id();
	if ( $current_member_id == $ID ) {
		if ( isset($plaintext_pass) ) {
			wp_clear_auth_cookie();
			wp_set_auth_cookie($ID);
		}
	}

	return $member_id;
}

function zm_logout_url() {
	return zm_format_url(get_bloginfo('url'), 'zm_action=logout');
}

function zm_create_member( $username, $password, $email, $status = 1 ) {
	$username = esc_sql($username);
	$email = esc_sql($email);
	$pass = $password;

	$memberdata = compact('username', 'email', 'pass', 'status');
	return zm_insert_member($memberdata, false, true);
}

function zm_insert_member( $memberdata, $confirmation = false, $background=false) {
	global $wpdb;
	
	if ( !is_array($memberdata) )
		return false;
	
	if ( !function_exists('wp_hash_password') )
		require_once(ABSPATH . 'wp-includes/pluggable.php');
	
	extract( $memberdata, EXTR_SKIP );

	// Are we updating or creating?
	if ( !empty($ID) ) {
		$ID = (int) $ID;
		$update = true;
		$old_member_data = zm_member($ID);
        
        if ( empty($email) ) $email = zm_isset($old_member_data->email);
        
	} else {
		$update = false;
		// Hash the password
		$plain_pass = isset($pass) ? $pass : zm_generate_password($email);
		//$pass = wp_hash_password($plain_pass);
		$pass = $plain_pass;
		update_option('zm_new_pass', $plain_pass);
	}
	
	if ( !isset($username) ) {
		if ( empty($email) ) zm_error('Cannot create a member with an empty email.');
		$username = strtolower(zm_generate_username($email, isset($first_name) ? $first_name : $email, isset($last_name) ? $last_name : ''));
	}
	
	$username = sanitize_user($username, true);
	$username = trim($username, true);
	$general = get_option('zm_general_option');
	
	if ( empty($username) )
		if(!$background) zm_error('Cannot create a member with an empty username.');

	if ( !$update && zm_username_exists($username) )
		if(!$background) zm_error( 'Sorry, that username already exists! Please login <a href="'.get_permalink($general['login_page']).'">here</a>.' );
	
	if ( !$update && zm_email_exists($email) )
		if(!$background) zm_error( 'Sorry, that email address is already used! Please login <a href="'.get_permalink($general['login_page']).'">here</a>.' );
	
	if ( empty($first_name) ) $first_name = '';
	if ( empty($last_name) ) $last_name = '';
	if ( empty($status) ) $status = 1;
	if ( empty($paypal_id) ) $paypal_id = '';
	if ( empty($metadata) ) $metadata = '';
	if ( empty($date) ) $date = zm_time();
	
	if ( is_array($metadata) )
		$metadata = maybe_serialize($metadata);
	
	$data = compact('email', 'pass', 'first_name', 'last_name', 'status', 'paypal_id', 'metadata', 'date');
	$data = stripslashes_deep($data);

	if ( $update ) {
		$wpdb->update("{$wpdb->prefix}zm_members", $data, compact( 'ID' ));
		$member_id = (int) $ID;
	} else {
		if ($confirmation) $data['status'] = 0;
		$wpdb->insert("{$wpdb->prefix}zm_members", $data + compact('username'));
		$member_id = (int) $wpdb->insert_id;
	}

	// delete caches
	wp_cache_delete($member_id, 'zm_members');
	wp_cache_delete($username, 'zm_memberlogins');

	if ( $update )
		do_action('zm_profile_update', $member_id, $old_member_data);
	else
		do_action('zm_member_register', $member_id);

	return $member_id;
}

function zm_delete_member( $member_id ) {
	global $wpdb;

	$id = (int) $member_id;
	$member = zm_member($id);
	if ( !$member )
		return false;
	
	do_action('zm_member_delete', $id);

	zm_clean_member_cache($member);
	$wpdb->delete("{$wpdb->prefix}zm_members", array('ID' => $id));
	
	do_action('zm_member_deleted', $id);
	return true;
}

function zm_member( $id = 0, $username = '' ) {
	if ( !empty($id) && !is_numeric($id) ) {
		$username = $id;
		$id = 0;
	}
	
	if ( $id )
		$data = zm_get_member_by('id', $id);
	else
		$data = zm_get_member_by('login', $username);

	if ( !$data || !is_object($data) ) return false;
	return $data;
}

function zm_get_member_by( $field, $value ) {
	global $wpdb;

	if ( 'id' == $field ) {
		// Make sure the value is numeric to avoid casting objects, for example,
		// to int 1.
		if ( !is_numeric($value) )
			return false;
		$value = absint($value);
	} else {
		$value = trim($value);
	}

	if ( !$value )
		return false;

	switch ( $field ) {
		case 'id':
			$member_id = $value;
			$db_field = 'ID';
			break;
			
		case 'email':
			$member_id = wp_cache_get($value, 'zm_memberemail');
			$db_field = 'email';
			break;
			
		case 'login':
			$value = sanitize_user($value);
			$member_id = wp_cache_get($value, 'zm_memberlogins');
			$db_field = 'username';
			break;
		default:
			return false;
	}

	if ( false !== $member_id ) {
		if ( $member = wp_cache_get($member_id, 'zm_members') )
			return $member;
	}

	if ( !$member = $wpdb->get_row($wpdb->prepare("SELECT * FROM `{$wpdb->prefix}zm_members` WHERE `$db_field` = %s", $value)) )
		return false;

	zm_update_member_caches($member);
	return $member;
}

function zm_update_member_caches( $member ) {
	wp_cache_set($member->ID, $member, 'zm_members');
	wp_cache_set($member->username, $member->ID, 'zm_memberlogins');
	wp_cache_set($member->email, $member->ID, 'zm_memberemail');
}

function zm_clean_member_cache( $member ) {
	if ( is_numeric($member) )
		$member = zm_member($member);
	if ( !is_object($member) ) return;
	
	wp_cache_delete($member->ID, 'zm_members');
	wp_cache_delete($member->username, 'zm_memberlogins');
	wp_cache_delete($member->email, 'zm_memberemail');
}

function zm_get_current_member() {
	if ( !$member_id = zm_validate_auth_cookie('', 'logged_in') )
		return false;
	
	$current_member = zm_member($member_id);
	return $current_member;
}

function zm_get_current_member_id() {
	if ( !is_zm_logged_in() ) return 0;
	$member = zm_get_current_member();
	return ( isset($member->ID) ) ? $member->ID : 0;
}

add_action('init', 'zm_free_register');
function zm_free_register(){
	if (isset($_GET['mode']) && $_GET['mode'] == 'register' && isset($_GET['type']) && $_GET['type'] == 'free'){
		//var_dump($_POST);
		$general = get_option('zm_general_option');
		
		if(is_zm_logged_in()){
			$member = zm_get_current_member();
			
			if(zm_is_subscribed($member->ID, $_POST['product_id'])) zm_error('You already have access to this product.');
			
			$meta = array(
				'product_id' => $_POST['product_id'],
				'member_id' => $member->ID,
				'type' => 'free',
				'paysys' => '-',
				'receipt' => '-',
				'amount' => 0,
				'is_rebill' => 0,
				'status' => 1, // '0' is pending; '1' is completed; '2' is canceled; '3' is expired; '4' is refunded
				'currency' => 'USD',
				'txn_id' => '',
				'other_id' => '',
				'ipaddr' => zm_get_ipaddr(),
				'begin_date' => zm_time(),
				'expired_date' => strtotime('19 Jan 2038 03:14:07 UTC'),
				'txn_date' => zm_time()
			);
			
			$txn_id = zm_add_payment($meta);
			
			$data = zm_get_row('product', $_POST['product_id']);

			if (zm_isset($data->download_id, false, true)){
				if ($data->download_id > 0){
					$page = get_page($data->download_id);
					if ($page){
						wp_redirect($data->download_id);
					}else{
						wp_redirect($general['after_login_page']);
					}
				}else{
					wp_redirect($data->thanks_url);
				}
			}else{
				wp_redirect($general['after_login_page']);
			}
			
			exit;
		}
		
		$captcha = true;
		$id = false;
		
		// is recaptcha enabled?
		if (isset($_POST["recaptcha_challenge_field"])){
			require_once ZM_API_RECAPTCHA;
			
			if ($privatekey = zm_isset($general['rc_private_key'])){
		  		$resp = recaptcha_check_answer ($privatekey,
		                                $_SERVER["REMOTE_ADDR"],
		                                $_POST["recaptcha_challenge_field"],
		                                $_POST["recaptcha_response_field"]);
		                                
				if (!$resp->is_valid) {
					// What happens when the CAPTCHA was entered incorrectly?
					$captcha = false;
		  		}
			}
		}
		
		if ($captcha){
			if (isset($_GET['confirmation']) && $_GET['confirmation'] == 'true')
		 		$id = zm_insert_member($_POST, true);
			else
				$id = zm_insert_member($_POST);
		}
		
		
		if ($id){
			if ( is_wp_error($id) )
   				die($id->get_error_message());
			
			$data = zm_get_row('product', $_POST['product_id']);
			$data->autoresponder = maybe_unserialize($data->autoresponder);
			$data->gotowebinar = maybe_unserialize($data->gotowebinar);
			
			//var_dump($page);
			//die('id :'. $data->download_id);
			//add payment
			$meta = array(
				'product_id' => $_POST['product_id'],
				'member_id' => $id,
				'type' => 'free',
				'paysys' => '',
				'receipt' => '',
				'amount' => 0,
				'is_rebill' => 0,
				'status' => 1, // '0' is pending; '1' is completed; '2' is canceled; '3' is expired; '4' is refunded
				'currency' => 'USD',
				'txn_id' => '',
				'other_id' => '',
				'ipaddr' => zm_get_ipaddr(),
				'begin_date' => zm_time(),
				'expired_date' => strtotime('19 Jan 2038 03:14:07 UTC'),
				'txn_date' => zm_time()
			);
            
			$txn_id = zm_add_payment($meta);
			
			if (isset($_GET['confirmation']) && $_GET['confirmation'] == 'true'){
				//SEND CONFIRMATION EMAIL HERE
				//zm_send_email(1, $id, array('id' => $data->ID, 'product' => $data->title));
				
				//SET COOKIE HERE.. IT's NOT A FOOD.. IT's DIFFERENT
				$cookie = zm_encode('zm|'.$_POST['product_id'], 'registration');
				@setcookie('__zm_'.$cookie, $id, zm_time()+172800, SITECOOKIEPATH);
			}
			
			zm_welcome_email($id, get_option('zm_new_pass'), $_POST['product_id'], $txn_id);
			
			
			//register to gotowebinar
			if (zm_isset($data->gotowebinar['enable']) == 'on'){
				zm_register_gotowebinar($data->gotowebinar['list'], $_POST);
			}
			
			//register to autoresponder
			if(zm_isset($data->autoresponder['enable']) == 'on'){
				if ($data->autoresponder['provider'] != 'custom'){
					zm_add_autoresponder($_POST, $data->autoresponder['provider'], $data->autoresponder['list']);
				}else{
					//Custom autoresponder here..
					do_action('zm_custom_autoresponder', $txn_id);
				}
			}
			
			if (isset($_POST['thanks-url'])){
				wp_redirect($_POST['thanks-url']);
				exit;
			}else{
				wp_redirect(get_permalink($general['after_login_page']));
				exit;
			}
		}else{
			$temp = $_SERVER['REQUEST_URI'] ? $_SERVER['REQUEST_URI'] : $_SERVER['PATH_INFO'];
			$url = explode('?', $temp);
			
			if (!$captcha)
				wp_redirect(zm_format_url($url[0], 'zm_captcha=false'));
			else
				wp_redirect(zm_format_url($url[0], 'zm_register=false'));
			
			exit;
		}
		//die();
	}
}

add_action('init', 'zm_force_download');
function zm_force_download(){
	if (isset($_GET['mode']) && $_GET['mode'] == 'download' && isset($_GET['file'])){
		
		$file_temp = explode('|', zm_decode($_GET['file'], 'zm'));
		
		if ($file_temp[0] == 2){
			$file_location = 's3';
			$file_bucket = zm_isset($file_temp[1]);
			$file_name = zm_isset($file_temp[2]);
		}else{
			$file_location = 'local';
			$file_name = zm_isset($file_temp[1]);
		}
		
		if ($file_location == 'local'){
			
			$file_path = ZM_DOWNLOAD.'/'.$file_name;
		
			if (is_file($file_path)){
				
				if (zm_is_protected($file_location.'_'.md5($file_name))){
					zm_check_page($file_location.'_'.md5($file_name), 'file');
				}
				
				//required for IE (YOU KNOW WHAT I MEAN)
				if(ini_get('zlib.output_compression')) { ini_set('zlib.output_compression', 'Off');	}
				
				//die($file_name);
				
				// get the file mime type using the file extension
				switch(strtolower(substr(strrchr($file_path, '.'), 1))) {
					case 'pdf': $mime = 'application/pdf'; break;
					case 'zip': $mime = 'application/zip'; break;
					case 'rar': $mime = 'application/x-rar-compressed'; break;
					case 'jpeg':
					case 'jpg': $mime = 'image/jpg'; break;
					case 'mp3': $mime = 'audio/mp3'; break;
					case 'mp4': $mime = 'video/mp4'; break;
					case 'flv': $mime = 'video/flv'; break;
					
					default: $mime = 'application/force-download';
				}
				
				$disposition = 'attachment';
				
				if (isset($_GET['stream']) && $_GET['stream'] == 'true'){
					$disposition = 'inline';
				}
				
				set_time_limit(0);
				ignore_user_abort(false);
				ini_set('output_buffering', 0);
				ini_set('zlib.output_compression', 0);
				
				$chunk = 10 * 1024 * 1024; // bytes per chunk (10 MB)
				
				$fp = fopen($file_path, "rb");
				 
				if ($fp === false) { 
				    die ("Unable open file"); 
				}
				
				header('Pragma: public'); 	// required
				header('Expires: 0');		// no cache
				header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
				header('Last-Modified: '.gmdate ('D, d M Y H:i:s', filemtime ($file_path)).' GMT');
				header('Cache-Control: private',false);
				header('Content-Type: '.$mime);
				header('Content-Disposition: '.$disposition.'; filename="'.basename($file_path).'"');
				header('Content-Transfer-Encoding: binary');
				header('Content-Length: '.filesize($file_path));	// provide file size
				header('Connection: close');
				
				while (!feof($fp))
				{
				    echo fread($fp, $chunk);
					
					ob_flush();  // flush output 
				    flush(); // this is essential for large downloads
				}  
				fclose($fp);

				//readfile($file_path);		// push it out
				exit();
			}else{
				zm_error('File not found OR has been deleted. Please contact site owner.');
			}
		}else if ($file_location == 's3'){
			if (zm_is_protected($file_location.'_'.$file_bucket.'_'.zm_encode($file_name, 'zm_s3'))){
				zm_check_page($file_location.'_'.$file_bucket.'_'.zm_encode($file_name, 'zm_s3'), 'file');
				
				if (isset($GET['type']) && $_GET['type'] == 'video'){
					return zm_s3_get_authenticated_url($file_bucket, $file_name);
				}else{
					wp_redirect(zm_s3_get_authenticated_url($file_bucket, $file_name));
					exit;
				}
			}else{
				if (isset($GET['type']) && $_GET['type'] == 'video'){
					return 'https://s3.amazonaws.com/'.$file_bucket.'/'.$file_name;
				}else{
					wp_redirect('https://s3.amazonaws.com/'.$file_bucket.'/'.$file_name);
					exit;
				}
			}
		}
	}
}

function zm_is_subscribed($member_id, $product_id){
	global $wpdb;
	
	$data = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}zm_payments WHERE member_id=".$member_id." AND product_id=".$product_id." AND status=1 AND expired_date >= ".zm_time());
	
	if ($data){
		return true;
	}else{
		return false;
	}
}

function zm_is_protected($id){
	if (is_numeric($id)){
		$data = zm_get_all('protect', array('post_id', $id));
        
        //var_dump($data);
        //die();
		if (!$data){
			if (get_post_type($id) == 'post'){
				$categories = get_the_category($id);
				$cat_ids = array();
				if ($categories){
					foreach ($categories as $category){
						$cat_ids[] = '"category_'.$category->cat_ID.'"';
					}
					
					//list of categories
					if (count($cat_ids) > 1){
						$category_ids = implode(', ', $cat_ids);
					}else{
						$category_ids = $cat_ids[0];
					}
					
					$data = zm_get_all('protect', array('filename', $category_ids), 'category');
				}
			}
		}
	}else{
		//..
		//checked protected files here
		$data = zm_get_all('protect', array('filename', $id), 'file');
	}
	
	if ($data){
		$product_ids = array();
		
		foreach ($data as $row){
			$product_ids[] = $row->product_id;
		}
		
		return $product_ids;
	}
	
	return false;
}

/* ======================================
 * END OF COUPON-RELATED FUNCTIONS
 * ====================================== */
 
function zm_register_gotowebinar($id, $data_user){
	// GET DATA
	$data = zm_get_row('product', $id);
	$data->gotowebinar = maybe_unserialize($data->gotowebinar);
	
	if (zm_isset($data->gotowebinar['enable']) == 'on'){
		if (is_array($data->gotowebinar['list'])){
			require_once ZM_CITRIX;
			
			$general_option = get_option('zm_general_option');
			$citrix = new Citrix($general_option['gtw_key']);
			
			$citrix->set_organizer_key(get_option('zm_gtw_key'));
			$citrix->set_access_token(get_option('zm_gtw_token'));
			
			foreach ($data->gotowebinar['list'] as $webinar){
				$citrix->citrixonline_create_registrant_of_webinar($webinar, $data = array('first_name' => $data_user['first_name'], 'last_name' => $data_user['last_name'], 'email'=> $data_user['email'])) ;
			}
		}
	}
}

function zm_s3_get_authenticated_url( $bucket, $filename, $lifetime = 1800 ) {
	//include the S3 class				
	if (!class_exists(ZM_LIBS . 'S3.php')) require_once(ZM_LIBS . 'S3.php');
	
	//AWS access info
	$general = get_option('zm_general_option');
	
	//instantiate the class
	$s3 = new S3(zm_isset($general['az_api']), zm_isset($general['az_key']));
	return $s3->getAuthenticatedURL($bucket, $filename, $lifetime, false, true);
}

/* ======================================
 * LOGS-RELATED FUNCTIONS
 * ====================================== */
function zm_get_ipn_log( $log_id, $paysys = 'zaxaa', $receipt = '', $product_id = 0 ) {
	global $wpdb;
	
	$sql = "SELECT * FROM `{$wpdb->prefix}zm_ipn_log` WHERE `tx_id` <> 0";
	if ( $log_id ) {
		$sql .= " AND `log_id` = %d";
		$query = $wpdb->prepare($sql, $log_id);
	} else {
		if ( !empty($product_id) ) {
			$sql .= " AND `paysys` = %s AND `receipt` = %s AND `product_id` = %d";
			$query = $wpdb->prepare($sql, $paysys, $receipt, $product_id);
		} else {
			$sql .= " AND `paysys` = %s AND `receipt` = %s";
			$query = $wpdb->prepare($sql, $paysys, $receipt);
		}
	}

	if ( !$ipn = $wpdb->get_row($query) ) return false;
	return $ipn;
}

function zm_log_ipn( $args, $log_id = 0 ) {
	global $wpdb;
	
	if ( $log_id ) {
		$update = true;
		if ( $ipn_obj = zm_get_ipn_log($log_id) ) {
			$old_ipn = get_object_vars($ipn_obj);
			$old_ipn = add_magic_quotes($old_ipn); // Escape data pulled from DB.
			$args = wp_parse_args($args, $old_ipn);
		}
	} else {
		$update = false;
	}
	
	extract( $args, EXTR_SKIP );
	
	if ( empty($tx_id) ) $tx_id = 0;
	if ( empty($product_id) ) $product_id = 0;
	if ( empty($member_id) ) $member_id = 0;
	if ( empty($pay_email) ) $pay_email = '';
	if ( empty($paysys) ) $paysys = '';
	if ( empty($receipt) ) $receipt = '';
	if ( empty($status) ) $status = 0;
	if ( empty($postdata) ) $postdata = '';
	if ( empty($date) ) $date = zm_time();
	
	if ( is_array($postdata) )
		$postdata = maybe_serialize($postdata);
		
	$data = compact('tx_id', 'product_id', 'member_id', 'pay_email', 'paysys', 'receipt', 'status', 'postdata', 'date');
	$data = stripslashes_deep($data);
	
	if ( $update )
		$wpdb->update("{$wpdb->prefix}zm_ipn_log", $data, compact('log_id'));
	else
		$wpdb->insert("{$wpdb->prefix}zm_ipn_log", $data);
	return $wpdb->insert_id;
}

function zm_log_error( $errordata ) {
	global $wpdb;
	
	$defaults = array(
		'member_id' => 0,
		'receipt' => '',
		'url' => esc_sql($_SERVER['REQUEST_URI']),
		'ip_addr' => $_SERVER['REMOTE_ADDR'],
		'referrer' => esc_sql(zm_isset($_SERVER['HTTP_REFERER'])),
		'error' => '',
		'type' => 'normal',
		'date' => zm_time()
	);
	$data = wp_parse_args($errordata, $defaults);
	$wpdb->insert("{$wpdb->prefix}zm_error_log", $data);
	return true;
}

function zm_ipn_error( $error, $receipt = '', $member_id = 0, $exit = true ) {
	$error = zm_sanitize($error);
	$error_log = zm_log_error("error={$error}&receipt={$receipt}&member_id={$member_id}&type=ipn");
	
	if ( $exit )
		exit;
}

add_action('init', 'zm_single_purchase_history');
function zm_single_purchase_history(){
	if (isset($_GET['page']) && $_GET['page'] == 'zm_purchase' && isset($_GET['mode']) && $_GET['mode'] == 'history' && isset($_GET['id']) && $_GET['id'] > 0  && isset($_GET['mid']) && $_GET['mid'] > 0){
		$product = zm_get_row('product', $_GET['id']);
		if ($product){
			$metadatas = zm_get_all('payment', array($_GET['id'], $_GET['mid']), 'history');
			
			if ($metadatas){
				$ptype = array('free' => 'Free', 'onetime' => 'One Time', 'subscription' => 'Subscription');
				$ppaysys = array('manual' => 'Manual', 'zaxaa' => 'Zaxaa', 'wsopro' => 'WSOPro', 'jvzoo' => 'JVZoo', 'paypal' => 'PayPal', 'clickbank' => 'Clickbank');
				$table = '';
				$table .= '<table class="zm-single-purchase-history">';
				$table .= '<tr>';
				$table .= '<th>Payment Number</th>';
				$table .= '<th>Payment System</th>';
				$table .= '<th colspan="2">Period</th>';
				$table .= '<th>Amount</th>';
				$table .= '<th>Status</th>';
				$table .= '</tr>';
				$i= 1;
				foreach ( $metadatas as $metadata ) {
					$title = $metadata->title;
					$type = $metadata->p_type;
					$txn_id = $metadata->txn_id;
					$receipt = $metadata->receipt;
					$date = !isset($date) ? $metadata->txn_date : $date;
					$paysys = $metadata->paysys;
					$status = zm_status($metadata->status, 'plain');
					
					if ($type == 'subscription'){
						$mode = zm_translate_rc_mode($metadata->subs_num, $metadata->subs_mode);
						$price = $metadata->rc_price;
						$amount = $metadata->amount;
						$discount = $metadata->rc_price-$metadata->amount;
					}else if ($type == 'onetime'){
						$price = $metadata->ot_price;
						$amount = $metadata->amount;
						$discount = $metadata->ot_price-$metadata->amount;
					}else{
						$price = 0.00;
						$amount = 0.00;
						$discount = 0.00;
					}
					
					$table .= '<tr>';
					$table .= '<td>Payment-'.$i.'</td>';
					$table .= '<td>'.$metadata->paysys.'</td>';
					$table .= '<td>'.date("M d, Y h:i:s A", $metadata->begin_date).'</td>';
					$table .= '<td>'.date("M d, Y h:i:s A", $metadata->expired_date).'</td>';
					$table .= '<td>'.$metadata->amount.'</td>';
					if (zm_time() > $metadata->expired_date){
						$table .= '<td><span class="gpf-label alert round">Expired</span></td>';
					}else{
						$table .= '<td>'.$status.'</td>';
					}
					$table .= '</tr>';
					$i++;
				}
				$table .= '</table>';
				
				?>
				<style>      
                .zm-purchase-zoom {
                font-family: consolas, "Open Sans", "Helvetica", Helvetica, Arial, sans-serif;
                color:#555;
				}
				.zm-purchase-zoom h1 {
					border-bottom:1px solid #ddd;
					padding-bottom:10px;
				}
				.zm-purchase-zoom p {
					padding-left:30px;
				}
				.zm-purchase-zoom span {
					font-weight:600;
					display:inline-block;
					width: 30%;
				}
				
				.zm-purchase-zoom em {
					border-bottom: 1px dashed #cecece;
					display: inline-block;
					width: 50%;
				}
				.zm-single-purchase-history{
					width: 100%;
					border-collapse: collapse;
				}
				.zm-single-purchase-history th{
					font-weight: normal;
					background: none repeat scroll 0% 0% rgb(241, 241, 241);
				}
				.zm-single-purchase-history th, .zm-single-purchase-history td{
					padding: 8px 10px;
					border: 1px solid rgb(221, 221, 221);
				}
                </style>
                <?php
				
				echo '<div class="zm-purchase-zoom">';
				echo '<h1>'.$title.'</h1>';
				
				if ($type == 'subscription'){
					echo '<h3>Product Details:</h3>';
					echo '<p><span>Regular Price</span> : <em>'.$price.'</em></p>';
					echo '<p><span>Discount</span> : <em>'.($discount > 0 ? $discount : '0.00').'</em></p>';
					echo '<p><span>Buy Price</span> : <em>'.$amount.'</em></p>';
					
					echo '<h3>Subscription Details:</h3>';
					echo '<p><span>Start From</span> : <em>'.date("M d, Y h:i:s A", $date).'</em></p>';
					echo '<p><span>Period</span> : <em>'.$mode.'</em></p>';
					echo $table;
				}else{
					echo '<h3>Product Details:</h3>';
					echo '<p><span>Regular Price</span> : <em>'.$price.'</em></p>';
					echo '<p><span>Discount</span> : <em>'.($discount > 0 ? $discount : '0.00').'</em></p>';
					echo '<p><span>Buy Price</span> : <em>'.$amount.'</em></p>';
					
					echo '<h3>Transaction Details:</h3>';
					echo '<p><span>Product Type</span> : <em>'.$ptype[$type].' Product</em></p>';
					echo '<p><span>Receipt</span> : <em>'.zm_isset($receipt, '-').'</em></p>';
					echo '<p><span>Date</span> : <em>'.date("M d, Y h:i:s A", $date).'</em></p>';
					echo '<p><span>Payment Processor</span> : <em>'.$ppaysys[$paysys].'</em></p>';
					echo '<p><span>Payment Status</span> : <em>'.$status.'</em></p>';
				}
				echo '</div>';
				die();
			}else{
				zm_error('No Payment History');
			}
		}else{
			zm_error('Product has been removed by owner.');
		}
	}
}

add_filter( 'the_content', 'zm_welcome_message', 20 );
function zm_welcome_message( $content ) {
	if (isset($_GET['zm_active'])){
		if ($_GET['zm_active'] == 'true'){
			$message = '<div class="zm-login-error success round"><i class="icon-ok-sign icon-large"></i> Congratulations. Your account has been activated.</div>';
			
			$content = $message.''.$content;
		}
	}

    // Returns the content.
    return $content;
}
