<?php
/* ======================================
 * PAYMENT-RELATED FUNCTIONS
 * ====================================== */
add_action('template_redirect', 'zm_notification_handler', 2);
function zm_notification_handler() {
	if ( isset($_GET['zm_notify']) && $_GET['zm_notify'] != '' ) {
		do_action('zm_verify_ipn_' . $_GET['zm_notify']);
		exit;
	}
}

add_action('template_redirect', 'zm_order_handler', 5);
function zm_order_handler() {
	if ( !empty($_GET['zm_order']) && !empty($_GET['zm_id']) ) {
		$paysys = rawurldecode(zm_sanitize($_GET['zm_order']));
		$product_id = intval($_GET['zm_id']);
		do_action('zm_order_handler_' . $paysys, $product_id);
	}
}

add_action('template_redirect', 'zm_thanks_handler', 3);
function zm_thanks_handler() {
	global $general_option;

	if ( !isset($_REQUEST['zm_return']) || !isset($_REQUEST['zm_id']) )
		return;

	$paysys = $_REQUEST['zm_return'];
	$product_id = intval($_REQUEST['zm_id']);

	global $wpdb;

	if ( !$product = zm_get_product($product_id) )
		wp_die('ERROR: Invalid Product.');

	$home_url = ( !empty($general_option['after_login_page']) ) ? get_permalink($general_option['after_login_page']) : get_bloginfo('url');
	$product_url = ( !empty($product->download_id) && $product->download_id > 0) ? get_permalink($product->download_id) : $home_url;
	$thanks_url = ( !empty($product->download_id) && $product->download_id == -1) ? (( zm_validate_url(trim($product->thanks_url)) ) ? trim($product->thanks_url) : $product_url) : $product_url;


	$payment = get_option('zm_payment_option');

	$rcpt = zm_sanitize($_REQUEST['rcpt'], '');

	if ( empty($rcpt) && isset($_REQUEST['tx']) ) {
		if ( !function_exists('curl_init') )
			wp_die('cURL extension hasn\'t been installed in your server. Please contact your host administrator.');

		$signature = ( isset($payment['zaxaa']['api']) ) ? $payment['zaxaa']['api'] : '';
		$tx = $_REQUEST['tx']; // token transaction
		$postfields = 'sid=' . $signature . '&tx=' . $tx;

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, 'https://www.zaxaa.com/notify/pdt');
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($ch, CURLOPT_TIMEOUT, 10);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_POST, true);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields);

		$response = curl_exec($ch);
		$code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

		curl_close($ch);

		// Zaxaa PDT is valid...
		// Do some action here...
		$vars = urldecode($response);
		parse_str($vars, $post);

		$rcpt = $post['trans_receipt'];
	}

	if ( empty($rcpt) ) {
		wp_redirect($thanks_url);
		exit;
	}

	if ( zm_isset($general_option['is_powered']) == 'on' ) {
		if ( zm_isset($general_option['aff_link']) ) {
			$aff_link = $general_option['aff_link'];
		}else{
			$aff_link = zaxaa_referral_url('https://www.zaxaa.com', false);
		}
	}

	$ipn = zm_get_ipn_log(0, 'zaxaa', $rcpt, $product_id);

	if ( $ipn ) {
		$vars = maybe_unserialize(str_replace('\'', '\\\'',$ipn->postdata));
		if ( !$payment = zm_get_payment($ipn->tx_id) )
			wp_die('ERROR: Invalid Payment');

		if ( $ipn->status == 1 ) { // check if IPN has been processed...
			// IPN has been processed... then redirect to members download page...

			if ($thanks_url == $product_url) wp_redirect($thanks_url);
			else wp_redirect(zm_format_url($general_option['login_page'], 'redir='.zm_encode($thanks_url, 'download')));

			exit;
		}

		$member_id = ( is_zm_logged_in() ) ? zm_get_current_member_id() : $payment->member_id;
		$is_logged_in = ( is_zm_logged_in() ) ? true : false;
		$is_existing = false;

		// clean up any login cookies...
		zm_clear_auth_cookie();

		if ( $is_logged_in ) {
			$is_existing = true;
		}

		// Recall payment data to make sure that we use latest data...
		//$payment = zm_get_payment($ipn->tx_id);

		// let's update ipn log...
		$update = zm_log_ipn( array('status' => 1), $ipn->log_id );

		//if ( !$is_existing && $temp_member->status == 1 )
			//$is_existing = true;

		//do_action('zm_custom_autoresponder', $payment->ID); // for custom autoresponder...

		if ( $is_existing ) {
			// re-logging in...
			zm_set_auth_cookie($member_id);

			// now redirecting...
			wp_redirect($thanks_url);
			exit;
		}


		$first_name = ucwords(strtolower(zm_sanitize($vars['cust_firstname'])));
		$last_name = ucwords(strtolower(zm_sanitize($vars['cust_lastname'])));

		// update member data...
		zm_update_member(
			array(
				'ID' => $member_id,
				//'email' => sanitize_email($vars[$args['email_var']]),
				'status' => 1,
				'first_name' => $first_name,
				'last_name' => $last_name,
				'paypal_id' => ( !empty($vars['payer_id']) ) ? $vars['payer_id'] : ''
			)
		);

		// logging in and then redirect...
		zm_set_auth_cookie($member_id);

		// send welcome email...
		//zm_welcome_email($member_id, $plain_pass, $product_id, $payment->ID);

		wp_redirect($thanks_url);
		exit;
	} else {
		$retries = get_transient('zm_retries_' . $rcpt);
		$thanks_url = zm_format_url(get_bloginfo('url'), http_build_query($_GET));
		if ( $paysys == 'zaxaa' && !empty($rcpt) && empty($_GET['rcpt']) )
			$thanks_url .= "&rcpt={$rcpt}";

		if ( $retries >= 15 ) {
			$page_title = 'Payment Error';
			$refresh = '';
			$message = '
				<p>We\'re sorry, but there\'s a problem in validating your payment. Please contact our <a href="#">support</a>.</p>
			';
		} else {
			$count = $retries + 1;
			set_transient('zm_retries_' . $rcpt, $count, 60*15);
			$page_title = 'Waiting For Payment Confirmation...';
			$refresh = '<meta http-equiv="refresh" content="5;URL=\'' . $thanks_url . '\'" />';
			$message = '
				<p style="text-align:center;"><img src="' . ZM_URL . 'images/loading.gif" border="0" /></p>
				<p style="text-align:center;">This page will be auto-refreshed every 5 seconds until your payment is confirmed.</p>
				<p style="text-align:center;"><strong>Please DO NOT close this page.</strong></p>
			';
		}
?>
<!DOCTYPE html>
<!--[if IE 6]>
<html id="ie6" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 7]>
<html id="ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html id="ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 6) | !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
<!--<![endif]-->
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<title><?php echo $page_title; ?></title>
<?php echo $refresh; ?>
<!--[if lt IE 9]>
	<script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
<![endif]-->
<link rel="profile" href="http://gmpg.org/xfn/11" />
<meta name="HandheldFriendly" content="True" />
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<!-- Adding "maximum-scale=1" fixes the Mobile Safari auto-zoom bug: http://filamentgroup.com/examples/iosScaleBug/ -->
<link rel="stylesheet" href="//fonts.googleapis.com/css?family=Open+Sans" type="text/css" media="all" />
<style type="text/css">
body {
	margin:0;
	padding:0;
	background-color:#F5F5F5;
	color:#808080;
}

#box_notice {
    width: 400px;
    margin: 70px auto;
    padding: 20px 0 0 0;
    font-size: 12px;
    color: #555;
    font-family: 'Open Sans', sans-serif;
    display: block;
    text-shadow: 0 1px 0 white;
    border: none;
    border-radius: 3px;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 1px 3px rgba(0,0,0,0.2);
    background-color: #FAFAFA;
    background-image: -webkit-gradient(linear, left top, left bottom, from(#FAFAFA), to(#EDEDED));
    background-image: -webkit-linear-gradient(top, #FAFAFA, #EDEDED);
    background-image: -moz-linear-gradient(top, #FAFAFA, #EDEDED);
    background-image: -o-linear-gradient(top, #FAFAFA, #EDEDED);
    background-image: -ms-linear-gradient(top, #FAFAFA, #EDEDED);
    background-image: linear-gradient(top, #FAFAFA, #EDEDED);
    filter: progid:DXImageTransform.Microsoft.gradient(GradientType=0,StartColorStr='#fafafa', EndColorStr='#ededed');
}

#box_notice .box_content {
	padding:15px 20px;
}

#box_notice h2 {
	margin:0 0 16px 0;
	padding:0;
    color: #555;
    text-align: center;
}

#box_notice p {
	margin:0 0 16px 0;
	padding:0;
    color: #555;
    font-size: 14px;
    text-align: center;
}

.hr {
    margin:0;
    padding:0;
    border-top:1px solid #ddd;
    border-bottom: 1px solid #fff;
}

</style>
</head>
<body>
<div id="box_notice">
	<h2><?php echo $page_title; ?></h2>
	<div class="hr"></div>
	<div class="box_content">
		<?php echo $message; ?>
		<?php if ( zm_isset($general_option['is_powered'], 'on', true) == 'on' ) : ?>
			<p style="color:#a7a7a7"><small><strong>Powered by</strong> <a href="<?php echo $aff_link; ?>" target="_blank" style="text-decoration: underline !important;">Zaxaa Member</a></small></p>
		<?php endif; ?>
	</div>
</div>
</body>
</html>
<?php
	exit;
	}
}

function zm_available_payments() {
	$payments = array( 'zaxaa.php' => 'zaxaa' );
	return $payments;
}

function zm_get_payment_settings( $product_id, $data ) {
	if ( $payments = zm_available_payments() ) {
		foreach ( $payments as $k => $v ) {
			do_action('zm_payment_settings_' . $v, $product_id, $data);
		}
	}
}

function zm_get_payment_config( $data , $type='') {
	if ( $payments = zm_available_payments() ) {
		foreach ( $payments as $k => $v ) {
			do_action('zm_payment_config_' . $v, $data, $type);
		}
	}
}

function zm_get_member_payments( $member_id ) {
	global $wpdb;
	$member_id = (int) $member_id;
	if ( !$payments = wp_cache_get($tx_id, 'zm_member_payments') ) {
	    $payments = $wpdb->get_results("SELECT * FROM `{$wpdb->prefix}zm_payments` WHERE `member_id` = {$member_id}");
		if ( !$payments )
			return false;

		wp_cache_add($member_id, $payments, 'zm_member_payments');
	}
	return $payments;
}

function zm_get_payment( $tx_id ) {
	global $wpdb;
	$tx_id = absint($tx_id);
	if ( $payment = wp_cache_get($tx_id, 'zm_payment') )
		return $payment;

    $payment = $wpdb->get_row(
    	"SELECT tx.*, m.username, p.title
		FROM {$wpdb->prefix}zm_payments tx
		LEFT JOIN {$wpdb->prefix}zm_members m ON (m.ID = tx.member_id)
		LEFT JOIN {$wpdb->prefix}zm_products p ON (p.ID = tx.product_id)
		WHERE tx.ID = {$tx_id}"
	);

	if ( !$payment ) return false;

	wp_cache_add($tx_id, $payment, 'zm_payment');
	return $payment;
}

function zm_add_payment( $args ) {
	global $wpdb;
	$defaults = array(
		'product_id' => 0,
		'member_id' => 0,
		'type' => 'onetime',
		'paysys' => 'manual',
		'receipt' => '',
		'amount' => 0.00,
		'is_rebill' => 0,
		'status' => 0, // '0' is pending; '1' is completed; '2' is canceled; '3' is expired; '4' is refunded
		'currency' => 'USD',
		'txn_id' => '',
		'other_id' => '',
		'ipaddr' => zm_get_ipaddr(),
		'begin_date' => zm_time(),
		'expired_date' => strtotime('19 Jan 2038', zm_time()),
		'txn_date' => zm_time()
	);
	$args = wp_parse_args( $args, $defaults );
	extract($args, EXTR_SKIP);

    if ( !$product_id )
    	return false;

  	$wpdb->insert("{$wpdb->prefix}zm_payments", $args);
    $tx_id = $wpdb->insert_id;

	//delete caches
	wp_cache_delete($member_id, 'zm_member_payments');
	wp_cache_delete($tx_id, 'zm_payment');

	if ( $status == 1 )
		do_action('zm_payment_completed', $tx_id);

	if ( $status == 2 )
		do_action('zm_subscription_canceled', $tx_id);

    return $tx_id;
}

function zm_update_payment( $tx_id, $data = array() ) {
	global $wpdb;

	if ( count($data) <= 0 ) return false; // if there's no data, don't bother to update the db...

	$tx_id = intval($tx_id);
	if ( !$payment = $wpdb->get_row("SELECT * FROM `{$wpdb->prefix}zm_payments` WHERE ID = {$tx_id}") )
		return false;

	$wpdb->update( "{$wpdb->prefix}zm_payments", $data, array('ID' => $tx_id) );

	// delete caches
	if ( isset($data['member_id']) );
		wp_cache_delete($data['member_id'], 'zm_member_payments');

	wp_cache_delete($payment->member_id, 'zm_member_payments');
	wp_cache_delete($tx_id, 'zm_payment');

	if ( isset($data['status']) && $data['status'] == 2 )
		do_action('zm_subscription_canceled', $tx_id);

    return $tx_id;
}

function zm_refund_payment( $tx_id ) {
	$new_data = array();
	$new_data['status'] = 4;
	$tx_id = zm_update_payment($tx_id, $new_data);
	return $tx_id;
}

function zm_payment_lock( $product_id, $receipt, $paysys ) {
	global $wpdb;

	$sql = $wpdb->prepare(
		"SELECT COUNT(*) FROM `{$wpdb->prefix}zm_payments`
		WHERE `product_id` = %d AND `receipt` = %s
		AND `paysys` = %s AND `is_rebill` = %d",
		$product_id, $receipt, $paysys, 0
	);

	$count = $wpdb->get_var($sql);
	if ( $count > 0 ) return true;
	return false;
}

function zm_get_expired( $type, $next_rebill='') {

	if ( $type != 'subscription' )
		return strtotime('19 Jan 2038', zm_time());

	return strtotime($next_rebill, zm_time());
}

/* ==========================================================
 * ZAXAA PAYMENT
 * ==========================================================*/

add_action('zm_payment_config_zaxaa', 'zm_zaxaa_payment_config', 10, 2);
function zm_zaxaa_payment_config( $data , $type = '' ) {

	$signature = zm_isset($data['zaxaa']['api'], '', true);
	if ( $type == 'wizard' ) :
		$default_sig = ZAXAA_SIGNATURE;
		if ( empty($signature) && !empty($default_sig) )
			$signature = $default_sig;
?>
	<div id="zm-pp-zaxaa" class="zm-pp-wizard-field">
<?php endif; ?>
		<div class="gpf-row collapse">
		    <div class="large-2 gpf-columns">
		      <span class="prefix radius">API Signature</span>
		    </div>
		    <div class="large-10 gpf-columns">
		    	<input type="text" name="zm_payments[zaxaa][api]" id="zm-zaxaa-api" value="<?php echo $signature; ?>" />
		    </div>
		    <div class="large-12 gpf-columns">
		   		<p>To obtain your Zaxaa API Signature, simply <a href="<?php zaxaa_referral_url('https://www.zaxaa.com/settings/account'); ?>" target="_blank"><span class="gpf-label round">click here</span></a> (you may need to login), go to tab "Account Settings" and click <span class="gpf-label orange round">Show API Signature</span> button.</p>
	    	</div>
    	</div>
    <?php if ( $type == 'wizard' ) : ?></div><?php endif;
}

add_action('zm_payment_settings_zaxaa', 'zm_zaxaa_product_settings', 10, 2);
function zm_zaxaa_product_settings( $product_id, $data ) {

	$zurl = ($product_id) ? zm_format_url(get_bloginfo('url'), 'zm_notify=zaxaa&zm_id='.$product_id) : 'You need to save this product to get this URL';
	$turl = ($product_id) ? zm_format_url(get_bloginfo('url'), 'zm_return=zaxaa&zm_id='.$product_id) : 'You need to save this product to get this URL';
?>
		<div class="gpf-row collapse">
		    <div class="large-3 gpf-columns">
		      <span class="prefix radius"><?php _e('Product Number / SKU', 'zm'); ?><span data-tooltip class="zm-help tip-top" title="Please edit the corresponding product in your Zaxaa account, then copy &amp; paste the &quot;Product Number/SKU&quot; here."></span></span>
		    </div>
		    <div class="large-9 gpf-columns">
		      <input class="digits" type="text" name="zm-payment-processor[zaxaa][pid]" id="zm-zx-pid" value="<?php echo stripslashes(zm_isset($data['zaxaa']['pid'])); ?>" />
		    </div>
		    <div class="large-3 gpf-columns">
		      <span class="prefix radius"><?php _e('Price Number', 'zm'); ?><span data-tooltip class="zm-help tip-top" title="If you're not using Zaxaa Multiple Pricing feature or if you don't know what this means, select &quot;1&quot;. If you use the Multiple Pricing feature, select which price this product corresponds to."></span></span>
		    </div>
		    <div class="large-9 gpf-columns">
		      	<select name="zm-payment-processor[zaxaa][price_num]" id="zm-price_num">
		      		<option value="1" <?php echo zm_isset($data['zaxaa']['price_num'], 1, true) == 1 ? 'selected="selected"' : ''; ?>>1</option>
					<option value="2" <?php echo zm_isset($data['zaxaa']['price_num'], 1, true) == 2 ? 'selected="selected"' : ''; ?>>2</option>
					<option value="3" <?php echo zm_isset($data['zaxaa']['price_num'], 1, true) == 3 ? 'selected="selected"' : ''; ?>>3</option>
					<option value="4" <?php echo zm_isset($data['zaxaa']['price_num'], 1, true) == 4 ? 'selected="selected"' : ''; ?>>4</option>
					<option value="5" <?php echo zm_isset($data['zaxaa']['price_num'], 1, true) == 5 ? 'selected="selected"' : ''; ?>>5</option>
      			</select>
		    </div>
		    <div class="large-3 gpf-columns">
		      <span class="prefix radius"><?php _e('ZPN URL', 'zm'); ?><span data-tooltip class="zm-help tip-top" title="To instantly validate new payments, please edit the product in Zaxaa, enable the &quot;Third Party Integration&quot; option, then enter this URL into the &quot;ZPN URL&quot; setting, and also enable the &quot;Zaxaa PDT&quot; option."></span></span>
		    </div>
		    <div class="large-9 gpf-columns" id="zm-zpn-col">
		      <input type="text" value="<?php echo $zurl ?>" onclick="this.focus(); this.select()" readonly />
		    </div>

		    <div class="large-3 gpf-columns">
		      <span class="prefix radius"><?php _e('Thank You / Delivery URL', 'zm'); ?><span data-tooltip class="zm-help tip-top" title="To give instant access to new members, please edit the product in Zaxaa, and enter this URL into the &quot;Thank You Page URL&quot; setting."></span></span>
		    </div>
		    <div class="large-9 gpf-columns" id="zm-zxreturn-col">
		      <input type="text" value="<?php echo $turl; ?>" onclick="this.focus(); this.select()" readonly />
		    </div>
		    <div class="large-3 gpf-columns" style="display: none">
		      <span class="prefix radius">Choose Currency</span>
		    </div>
		    <div class="large-9 gpf-columns" style="display: none">
		    	<select name="zm-payment-processor[zaxaa][currency]" id="zm-currency">
					<?php
					$currencies = zm_currencies();
					foreach ( $currencies as $k => $v ) {
						$selected = zm_isset($data['zaxaa']['currency'], 'USD') == $k  ? ' selected="selected"' : '';
						echo "<option value='{$k}'{$selected}>{$v}</option>";
					}
					?>
	      		</select>
		    </div>
   	 	</div>
<?php
}

add_action('zm_verify_ipn_zaxaa', 'zm_zaxaa_verify_ipn');
function zm_zaxaa_verify_ipn() {
	// Read POST data
	$posts = ( !isset($_POST) && !empty($_REQUEST['trans_type']) ) ? $_REQUEST : $_POST;
	if ( empty($posts['trans_type']) ) return false;
	$payment = get_option('zm_payment_option');
	$signature = ( isset($payment['zaxaa']['api']) ) ? trim($payment['zaxaa']['api']) : '';

	$trans_type = $posts['trans_type'];
	$trans_receipt = $posts['trans_receipt'];
	$trans_amount = $posts['trans_amount'];
	$seller_id = $posts['seller_id'];
	$hash_key = $posts['hash_key'];

	$our_hash = strtoupper(md5($seller_id . $signature . $trans_receipt . $trans_amount));
	if ( $our_hash != $hash_key ) {
		zm_ipn_error("Zaxaa ZPN validation failed. Calc: {$our_hash}, Rev: {$hash_key}", $trans_receipt);
	}

	zm_zaxaa_process_ipn($posts);
}

function zm_zaxaa_process_ipn( $vars ) {
	global $wpdb;

	$trans_type = $vars['trans_type'];
	$trans_receipt = $vars['trans_receipt'];
	$trans_amount = $vars['trans_amount'];
	$seller_id = $vars['seller_id'];
	$products = $vars['products'];

	$payer_email = sanitize_email($vars['cust_email']);
	$parts = explode("@", $payer_email);
	$first_name = ( !empty($vars['cust_firstname']) ) ? zm_sanitize($vars['cust_firstname']) : zm_sanitize($parts[0]);
	$last_name = zm_sanitize($vars['cust_lastname']);

	$id = zm_isset($_GET['zm_id'], 0 ,true);
	$temp_password = '';

	switch ( $trans_type ) {
		case 'SALE':
		case 'FIRST_BILL':
			foreach ( $products as $zproduct ) {
				$pricenum = zm_isset($zproduct['price_num'], 1);
				$sku = $zproduct['prod_number'];
				$type = $zproduct['payment_type'];

				if ( !$product = zm_get_productby_sku($sku, $pricenum) ) {
					zm_ipn_error("Cannot found Zaxaa product with sku:{$sku}", $trans_receipt, 0, false);
					continue;
				}

				if ( !$member_id = zm_email_exists($payer_email) ) {
					// let's create a new user...
					$username = zm_generate_username($payer_email, $first_name, $last_name);
					$temp_password = wp_generate_password(8, false);
					$member_id = zm_create_member($username, $temp_password, $payer_email);

					if ( is_wp_error($member_id) ){
						zm_ipn_error('Cannot create new member in Zaxaa ZPN (' . $member_id->get_error_code() . ')', $trans_receipt, 0, false);
						continue;
					}
				}

				// Add payment transaction data...
				$paydata = array(
					'product_id' => $product->ID,
					'member_id' => $member_id,
					'type' => ( $type == 'subscription' ) ? 'subscription' : 'onetime',
					'paysys' => 'zaxaa',
					'receipt' => $trans_receipt,
					'amount' => $zproduct['amount'],
					'is_rebill' => 0,
					'txn_id' => ( isset($vars['paypal_txn_id']) ) ? $vars['paypal_txn_id'] : '',
					'other_id' => ( isset($zproduct['recurring_id']) ) ? $zproduct['recurring_id'] : '',
					'status' => 1, // '0' is pending; '1' is completed; '2' is canceled; '3' is expired; '4' is refunded
					'expired_date' => zm_get_expired($type, zm_isset($zproduct['next_rebill'], 0))
				);

				$tx_id = zm_add_payment($paydata);

				zm_welcome_email($member_id, $temp_password, $product->ID, $tx_id);

				// log the ipn for further checking and usage...
				$ipndata = array(
					'tx_id' => $tx_id,
					'product_id' => $product->ID,
					'member_id' => $member_id, //$member_id,
					'pay_email' => $payer_email,
					'paysys' => 'zaxaa',
					'receipt' => $trans_receipt,
					'status' => 0, // '0' is unprocessed/unclaim; '1' is processed/claimed;
					'postdata' => $vars
				);

				$ipn = zm_log_ipn($ipndata);
			}
			break;

		case 'REBILL':
			foreach ( $products as $product ) {
				$sku = $product['prod_number'];
				$recurring_id = $product['recurring_id'];
				$recurring_status = $product['recurring_status'];
				if ( $payment = zm_zaxaa_last_payment($trans_receipt, $recurring_id) ) {
					$member_id = $payment->member_id;

					// Update existing payment status first...
					$new_data = array();
					$new_data['status'] = 3; // set the status to expired...
					$new_data['expired_date'] = strtotime('yesterday', zm_time());
					zm_update_payment($payment->ID, $new_data);

					$expired_date = zm_get_expired('subscription', zm_isset($product['next_rebill']));

					if ( $recurring_status == 'COMPLETED' )
						$expired_date = strtotime("19 Jan 2038", zm_time());

					$paydata = array(
						'product_id' => $payment->product_id,
						'member_id' => $member_id,
						'type' => 'subscription',
						'paysys' => 'zaxaa',
						'receipt' => $trans_receipt,
						'amount' => $product['amount'],
						'is_rebill' => 1,
						'status' => 1, // '0' is pending; '1' is completed; '2' is canceled; '3' is expired; '4' is refunded
						'expired_date' => $expired_date
					);

					$tx_id = zm_add_payment($paydata);

					// log the ipn for further checking and usage...
					/*$ipndata = array(
						'tx_id' => $tx_id,
						'product_id' => $payment->product_id,
						'member_id' => $member_id, //$member_id,
						'pay_email' => sanitize_email($vars['cust_email']),
						'paysys' => 'zaxaa-rebill',
						'receipt' => $trans_receipt,
						'status' => 0, // '0' is unprocessed/unclaim; '1' is processed/claimed;
						'postdata' => $vars
					);

					$ipn = zm_log_ipn($ipndata); */
				}
			}
			break;

		case 'CANCELED':
			// Subscription is canceled
			foreach ( $products as $product ) {
				$sku = $product['prod_number'];
				$recurring_id = $product['recurring_id']; // This might be useful to recognize past recurring payments
				if ( $payment = zm_zaxaa_last_payment($trans_receipt, $recurring_id) ) {

					if (zm_isset($payment->status) != 4){ // IF REFUND IGNORE IT
						$new_data = array();
						$new_data['status'] = 2; // set the status to cancelled...
						$tx_id = zm_update_payment($payment->ID, $new_data);

						// log the ipn for further checking and usage...
						$ipndata = array(
							'tx_id' => $tx_id,
							'product_id' => $payment->product_id,
							'member_id' => $payment->member_id, //$member_id,
							'pay_email' => $payer_email,
							'paysys' => 'zaxaa',
							'receipt' => $trans_receipt,
							'status' => ($tx_id) ? 1 : 0, // '0' is unprocessed/unclaim; '1' is processed/claimed;
							'postdata' => $vars
						);

						$ipn = zm_log_ipn($ipndata);
					}
				}
			}
			break;

		case 'REFUND':
			// Refunded payment...
			$refund = false;
			$pid = 0;
			foreach ( $products as $product ) {
				$recurring_id = ( !empty($product['recurring_id']) ) ? $product['recurring_id'] : '';

				if (!$recurring_id){
					$pricenum = zm_isset($product['price_num'], 1);
					$sku = $product['prod_number'];
					$type = $product['payment_type'];

					if ( !$product = zm_get_productby_sku($sku, $pricenum) ) {
						zm_ipn_error("Cannot found Zaxaa ONETIME product with sku:{$sku}", $trans_receipt, 0, false);
						continue;
					}

					$pid = $product->ID;
				}

				if ( $payment = zm_zaxaa_last_payment($trans_receipt, $recurring_id, $pid)) {
					//if ( $payments = zm_get_member_payments($payment->member_id) ) {
						//foreach ( $payments as $p ) {
							//if ( $p->product_id  == $payment->product_id && $p->status == 1 && $trans_receipt == $p->receipt ) {
									$tx_id = zm_refund_payment($payment->ID);

									// log the ipn for further checking and usage...
									$ipndata = array(
										'tx_id' => $tx_id,
										'product_id' => $payment->product_id,
										'member_id' => $payment->member_id, //$member_id,
										'pay_email' => $payer_email,
										'paysys' => 'zaxaa',
										'receipt' => $trans_receipt,
										'status' => ($tx_id) ? 1 : 0, // '0' is unprocessed/unclaim; '1' is processed/claimed;
										'postdata' => $vars
									);

									$ipn = zm_log_ipn($ipndata);
									$refund = true;
							//}
						//}
					//}
				}else{
					zm_ipn_error('Cannot find last payment of (member ' . $payer_email . ' & recurring ID '.$recurring_id.')', $trans_receipt, 0, false);
					continue;
				}

				if (!$refund){
					zm_ipn_error('Cannot find any payment for (member ' . $payer_email . ' & recurring ID '.$recurring_id.')', $trans_receipt, 0, false);
					continue;
				}
			}
			break;
	}
	exit;
}

function zm_zaxaa_last_payment( $receipt, $recurring_id, $product_id=0) {
	global $wpdb;

	if ($product_id){
		$last_payment = $wpdb->get_row(
			$wpdb->prepare("SELECT * FROM `{$wpdb->prefix}zm_payments`
				WHERE `product_id` = %d AND `receipt` = %s ORDER BY ID DESC LIMIT 1",
				$product_id, $receipt
			)
		);
	}else{
		$last_payment = $wpdb->get_row(
			$wpdb->prepare("SELECT * FROM `{$wpdb->prefix}zm_payments`
				WHERE `receipt` <> '' AND (`other_id` = %s OR `receipt` = %s) ORDER BY ID DESC LIMIT 1",
				$product_id, $receipt
			)
		);
	}

	if ( !$last_payment )
		return false;

	return $last_payment;
}
